CREATE TABLE IF NOT EXISTS medium (
	id INTEGER PRIMARY KEY,
	name TEXT NOT NULL UNIQUE,
	description NTEXT,
	reference NTEXT
);
INSERT INTO "medium" VALUES(1,'Blood','Blood medium','https://doi.org/10.1371/journal.pcbi.1010903');
INSERT INTO "medium" VALUES(2,'CasA','Casamino Acids medium','https://doi.org/10.1080/00275514.1971.12019223');
INSERT INTO "medium" VALUES(3,'CGXII','Corynebacterium glutamicum optimized growth medium','https://doi.org/10.1002/bit.25103');
INSERT INTO "medium" VALUES(4,'dGMM','Defined Gut Microbiota Medium','https://doi.org/10.1038/s41564-018-0123-9');
INSERT INTO "medium" VALUES(5,'LB','Lysogeny broth','https://doi.org/10.1093/nar/gky537, https://doi.org/10.1074/jbc.M703759200');
INSERT INTO "medium" VALUES(6,'M9','M9 minimal medium','https://www.sigmaaldrich.com/DE/de/product/sigma/m6030, https://doi.org/10.3389/fbinf.2023.1214074');
INSERT INTO "medium" VALUES(7,'MP-AU','Multi-Purpose Artificial Urine','https://doi.org/10.1038/s41598-019-56693-4, https://doi.org/10.1016/j.bios.2022.114962');
INSERT INTO "medium" VALUES(8,'RPMI','Roswell Park Memorial Institute 1640 Medium','https://www.thermofisher.com/de/de/home/technical-resources/media-formulation.114.html (visited on 2023-03-22)');
INSERT INTO "medium" VALUES(9,'SNM3','Synthetic Nasal Medium Version 3','https://doi.org/10.1371/journal.ppat.1003862');
INSERT INTO "medium" VALUES(10,'artSw','Artificial Sweat','https://doi.org/10.1128/spectrum.04180-22, Table 1');
INSERT INTO "medium" VALUES(11,'BMS23','Basal Medium as described in Swaney et al. 2023','https://doi.org/10.1128/spectrum.04180-22, Material & Methods; M9 components from: https://www.sigmaaldrich.com/DE/de/product/sigma/m6030');


CREATE TABLE IF NOT EXISTS "medium2substance" (
	medium_id INTEGER,
	substance_id INTEGER,
	flux NUMERIC DEFAULT NULL,
	source NTEXT,
	FOREIGN KEY(medium_id) REFERENCES medium(id),
	FOREIGN KEY(substance_id) REFERENCES substance(id),
	PRIMARY KEY(medium_id, substance_id)
);
INSERT INTO "medium2substance" VALUES(5,102,NULL,'Carbohydrates (Glucose)');
INSERT INTO "medium2substance" VALUES(5,164,NULL,'Alanine');
INSERT INTO "medium2substance" VALUES(5,169,NULL,'Aspartic acid');
INSERT INTO "medium2substance" VALUES(5,175,NULL,'Glutamic acid');
INSERT INTO "medium2substance" VALUES(5,178,NULL,'Histidine');
INSERT INTO "medium2substance" VALUES(5,182,NULL,'Leucine');
INSERT INTO "medium2substance" VALUES(5,186,NULL,'Methionine');
INSERT INTO "medium2substance" VALUES(5,189,NULL,'Proline');
INSERT INTO "medium2substance" VALUES(5,192,NULL,'Threonine');
INSERT INTO "medium2substance" VALUES(5,195,NULL,'Tyrosine');
INSERT INTO "medium2substance" VALUES(5,166,NULL,'Arginine');
INSERT INTO "medium2substance" VALUES(5,162,NULL,'Cystine');
INSERT INTO "medium2substance" VALUES(5,138,NULL,'Glycine');
INSERT INTO "medium2substance" VALUES(5,180,NULL,'Isoleucine');
INSERT INTO "medium2substance" VALUES(5,183,NULL,'Lysine');
INSERT INTO "medium2substance" VALUES(5,188,NULL,'Phenylalanine');
INSERT INTO "medium2substance" VALUES(5,190,NULL,'Serine');
INSERT INTO "medium2substance" VALUES(5,194,NULL,'Tryptophan');
INSERT INTO "medium2substance" VALUES(5,196,NULL,'Valine');
INSERT INTO "medium2substance" VALUES(5,270,NULL,'Thiamine (Vitamin B1)');
INSERT INTO "medium2substance" VALUES(5,246,NULL,'Riboflavin (Vitamin B2)');
INSERT INTO "medium2substance" VALUES(5,25,NULL,'Calcium pantothenate (Vitamin B5)');
INSERT INTO "medium2substance" VALUES(5,26,NULL,'Pyridoxine (Vitamin B6)');
INSERT INTO "medium2substance" VALUES(5,66,NULL,'Biotin (Vitamin B8)');
INSERT INTO "medium2substance" VALUES(5,211,NULL,'Folic acid (Vitamin B9)');
INSERT INTO "medium2substance" VALUES(5,87,NULL,'Cyanocobalamin (Vitamin B12)');
INSERT INTO "medium2substance" VALUES(5,88,NULL,'Cyanocobalamin (Vitamin B12)');
INSERT INTO "medium2substance" VALUES(5,285,NULL,'Cyanocobalamin (Vitamin B12)');
INSERT INTO "medium2substance" VALUES(5,240,NULL,'Niacin (Vitamin PP)');
INSERT INTO "medium2substance" VALUES(5,251,NULL,'Sodium, Selenium');
INSERT INTO "medium2substance" VALUES(5,81,NULL,'Chloride');
INSERT INTO "medium2substance" VALUES(5,258,NULL,'Sulfate');
INSERT INTO "medium2substance" VALUES(5,235,NULL,'Potassium');
INSERT INTO "medium2substance" VALUES(5,232,NULL,'Phosphorus (phosphate)');
INSERT INTO "medium2substance" VALUES(5,75,NULL,'Calcium pantothenate (Vitamin B5), Calcium');
INSERT INTO "medium2substance" VALUES(5,201,NULL,'Magnesium');
INSERT INTO "medium2substance" VALUES(5,289,NULL,'Zinc');
INSERT INTO "medium2substance" VALUES(5,62,NULL,'Arsenic');
INSERT INTO "medium2substance" VALUES(5,72,NULL,'Cadmium');
INSERT INTO "medium2substance" VALUES(5,207,NULL,'Mercury');
INSERT INTO "medium2substance" VALUES(5,198,NULL,'Lead');
INSERT INTO "medium2substance" VALUES(5,155,NULL,'Inosine');
INSERT INTO "medium2substance" VALUES(5,153,NULL,'Hypoxanthine');
INSERT INTO "medium2substance" VALUES(5,117,NULL,'Deoxycytidine');
INSERT INTO "medium2substance" VALUES(5,274,NULL,'Thymidine');
INSERT INTO "medium2substance" VALUES(5,279,NULL,'Uracil');
INSERT INTO "medium2substance" VALUES(5,282,NULL,'Uridine');
INSERT INTO "medium2substance" VALUES(5,115,NULL,'Deoxyadenosine');
INSERT INTO "medium2substance" VALUES(5,55,NULL,'Adenosine');
INSERT INTO "medium2substance" VALUES(5,84,NULL,'Chorismate');
INSERT INTO "medium2substance" VALUES(5,120,NULL,'O2 (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,150,NULL,'H+ (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,286,NULL,'H2O (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,37,NULL,'AMP (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,71,NULL,'CMP (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,85,NULL,'Chromate (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,173,NULL,'L-Cysteine (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,89,NULL,'Co2+ (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,90,NULL,'Cu2+ (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,156,NULL,'Fe2+ (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,157,NULL,'Fe3+ (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,39,NULL,'GMP (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,144,NULL,'Guanosine (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,152,NULL,'Hydrogen sulfide (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,36,NULL,'Lipoate (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,204,NULL,'Mn2+ (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,269,NULL,'Molybdate (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,56,NULL,'Ammonium (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,214,NULL,'Ni2+ (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,238,NULL,'Protoheme (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,30,NULL,'Pyridoxal (CarveMe)');
INSERT INTO "medium2substance" VALUES(5,44,NULL,'UMP (CarveMe)');
INSERT INTO "medium2substance" VALUES(6,75,NULL,'CaCl2*2H2O');
INSERT INTO "medium2substance" VALUES(6,81,NULL,'NaCl, NH4Cl, CaCl2*2H2O');
INSERT INTO "medium2substance" VALUES(6,102,NULL,'Glucose');
INSERT INTO "medium2substance" VALUES(6,286,NULL,'MgSO4*7H2O, CaCl2*2H2O');
INSERT INTO "medium2substance" VALUES(6,150,NULL,'KH2PO4, Na2HPO4');
INSERT INTO "medium2substance" VALUES(6,235,NULL,'KH2PO4');
INSERT INTO "medium2substance" VALUES(6,201,NULL,'MgSO4*7H2O');
INSERT INTO "medium2substance" VALUES(6,251,NULL,'NaCl, Na2HPO4');
INSERT INTO "medium2substance" VALUES(6,56,NULL,'NH4Cl');
INSERT INTO "medium2substance" VALUES(6,120,NULL,'Oxygen');
INSERT INTO "medium2substance" VALUES(6,232,NULL,'KH2PO4, Na2HPO4');
INSERT INTO "medium2substance" VALUES(6,258,NULL,'MgSO4*7H2O');
INSERT INTO "medium2substance" VALUES(9,164,NULL,'Alanine');
INSERT INTO "medium2substance" VALUES(9,166,NULL,'Arginine');
INSERT INTO "medium2substance" VALUES(9,173,NULL,'Cysteine');
INSERT INTO "medium2substance" VALUES(9,175,NULL,'Glutamic acid');
INSERT INTO "medium2substance" VALUES(9,138,NULL,'Glycine');
INSERT INTO "medium2substance" VALUES(9,178,NULL,'Histidine');
INSERT INTO "medium2substance" VALUES(9,182,NULL,'Leucin');
INSERT INTO "medium2substance" VALUES(9,183,NULL,'Lysine');
INSERT INTO "medium2substance" VALUES(9,105,NULL,'Ornithine');
INSERT INTO "medium2substance" VALUES(9,187,NULL,'Ornithine');
INSERT INTO "medium2substance" VALUES(9,188,NULL,'Phenylalanine');
INSERT INTO "medium2substance" VALUES(9,189,NULL,'Proline');
INSERT INTO "medium2substance" VALUES(9,190,NULL,'Serine');
INSERT INTO "medium2substance" VALUES(9,192,NULL,'Threonine');
INSERT INTO "medium2substance" VALUES(9,194,NULL,'Tryptophane');
INSERT INTO "medium2substance" VALUES(9,196,NULL,'Valine');
INSERT INTO "medium2substance" VALUES(9,16,NULL,'Citric acid');
INSERT INTO "medium2substance" VALUES(9,4,NULL,'Fumaric acid');
INSERT INTO "medium2substance" VALUES(9,202,NULL,'Maleic acid');
INSERT INTO "medium2substance" VALUES(9,242,NULL,'Pyruvic acid');
INSERT INTO "medium2substance" VALUES(9,256,NULL,'Succinic acid');
INSERT INTO "medium2substance" VALUES(9,102,NULL,'Glucose');
INSERT INTO "medium2substance" VALUES(9,281,NULL,'Urea');
INSERT INTO "medium2substance" VALUES(9,251,NULL,'Sodium, Sodium phosphate buffer (pH7.2), NaCl, MoNa2O4');
INSERT INTO "medium2substance" VALUES(9,81,NULL,'Chloride, NaCl, KCl, ZnCl2, MnCl2, CoCl2, CuCl2, NiCl2, Pyridoxamine-2HCl, Thiamine-dichoride');
INSERT INTO "medium2substance" VALUES(9,235,NULL,'Potassium, KCl');
INSERT INTO "medium2substance" VALUES(9,232,NULL,'Phosphate, Sodium phosphate buffer (pH7.2)');
INSERT INTO "medium2substance" VALUES(9,201,NULL,'Magnesium, MgSO4');
INSERT INTO "medium2substance" VALUES(9,258,NULL,'Sulphate');
INSERT INTO "medium2substance" VALUES(9,13,NULL,'2,2-Bipyridine');
INSERT INTO "medium2substance" VALUES(9,75,NULL,'Ca-D-Panthothenic acid');
INSERT INTO "medium2substance" VALUES(9,289,NULL,'ZnCl2');
INSERT INTO "medium2substance" VALUES(9,204,NULL,'MnCl2');
INSERT INTO "medium2substance" VALUES(9,89,NULL,'CoCl2');
INSERT INTO "medium2substance" VALUES(9,90,NULL,'CuCl2');
INSERT INTO "medium2substance" VALUES(9,214,NULL,'NiCl2');
INSERT INTO "medium2substance" VALUES(9,269,NULL,'MoNa2O4');
INSERT INTO "medium2substance" VALUES(9,87,NULL,'Cyanocobalamine');
INSERT INTO "medium2substance" VALUES(9,88,NULL,'Cyanocobalamine');
INSERT INTO "medium2substance" VALUES(9,285,NULL,'Cyanocobalamine');
INSERT INTO "medium2substance" VALUES(9,28,NULL,'p-Aminobenzoic acid');
INSERT INTO "medium2substance" VALUES(9,66,NULL,'Biotin');
INSERT INTO "medium2substance" VALUES(9,240,NULL,'Nicotinic acid');
INSERT INTO "medium2substance" VALUES(9,25,NULL,'Ca-D-Panthothenic acid');
INSERT INTO "medium2substance" VALUES(9,27,NULL,'Pyridoxamine-2HCl');
INSERT INTO "medium2substance" VALUES(9,270,NULL,'Thiamine-dichoride');
INSERT INTO "medium2substance" VALUES(9,150,NULL,'Pyridoxamine-2HCl, Thiamine-dichoride');
INSERT INTO "medium2substance" VALUES(9,246,NULL,'Riboflavin');
INSERT INTO "medium2substance" VALUES(9,120,NULL,'Oxygen');
INSERT INTO "medium2substance" VALUES(9,286,NULL,'Water');
INSERT INTO "medium2substance" VALUES(9,76,NULL,'Carbon dioxide');
INSERT INTO "medium2substance" VALUES(8,75,NULL,'D-Calcium pantothenate, Calcium nitrate (Ca(NO3)2 4H2O)');
INSERT INTO "medium2substance" VALUES(8,217,NULL,'Calcium nitrate (Ca(NO3)2 4H2O)');
INSERT INTO "medium2substance" VALUES(8,201,NULL,'Magnesium Sulfate (MgSO4) (anhyd.)');
INSERT INTO "medium2substance" VALUES(8,258,NULL,'Magnesium Sulfate (MgSO4) (anhyd.)');
INSERT INTO "medium2substance" VALUES(8,81,NULL,'L-Cystine 2HCl, L-Lysine hydrochloride, Choline chloride, Pyridoxine hydrochloride, Thiamine hydrochloride, Potassium Chloride (KCl), Sodium Chloride (NaCl)');
INSERT INTO "medium2substance" VALUES(8,235,NULL,'Potassium Chloride (KCl)');
INSERT INTO "medium2substance" VALUES(8,251,NULL,'L-Tyrosine disodium salt dihydrate, Sodium Bicarbonate (NaHCO3), Sodium Chloride (NaCl), Sodium Phosphate dibasic (Na2HPO4) anhydrous');
INSERT INTO "medium2substance" VALUES(8,232,NULL,'Sodium Phosphate dibasic (Na2HPO4) anhydrous');
INSERT INTO "medium2substance" VALUES(8,138,NULL,'Glycine');
INSERT INTO "medium2substance" VALUES(8,166,NULL,'L-Arginine');
INSERT INTO "medium2substance" VALUES(8,168,NULL,'L-Asparagine');
INSERT INTO "medium2substance" VALUES(8,169,NULL,'L-Aspartic acid');
INSERT INTO "medium2substance" VALUES(8,162,NULL,'L-Cystine 2HCl');
INSERT INTO "medium2substance" VALUES(8,175,NULL,'L-Glutamic Acid');
INSERT INTO "medium2substance" VALUES(8,176,NULL,'L-Glutamine');
INSERT INTO "medium2substance" VALUES(8,178,NULL,'L-Histidine');
INSERT INTO "medium2substance" VALUES(8,180,NULL,'L-Isoleucine');
INSERT INTO "medium2substance" VALUES(8,182,NULL,'L-Leucine');
INSERT INTO "medium2substance" VALUES(8,186,NULL,'L-Methionine');
INSERT INTO "medium2substance" VALUES(8,188,NULL,'L-Phenylalanine');
INSERT INTO "medium2substance" VALUES(8,189,NULL,'L-Proline');
INSERT INTO "medium2substance" VALUES(8,190,NULL,'L-Serine');
INSERT INTO "medium2substance" VALUES(8,192,NULL,'L-Threonine');
INSERT INTO "medium2substance" VALUES(8,194,NULL,'L-Tryptophan');
INSERT INTO "medium2substance" VALUES(8,195,NULL,'L-Tyrosine disodium salt dihydrate');
INSERT INTO "medium2substance" VALUES(8,196,NULL,'L-Valine');
INSERT INTO "medium2substance" VALUES(8,183,NULL,'L-Lysine hydrochloride');
INSERT INTO "medium2substance" VALUES(8,66,NULL,'Biotin');
INSERT INTO "medium2substance" VALUES(8,83,NULL,'Choline chloride');
INSERT INTO "medium2substance" VALUES(8,213,NULL,'Niacinamide');
INSERT INTO "medium2substance" VALUES(8,28,NULL,'Para-Aminobenzoic Acid');
INSERT INTO "medium2substance" VALUES(8,246,NULL,'Riboflavin');
INSERT INTO "medium2substance" VALUES(8,270,NULL,'Thiamine hydrochloride');
INSERT INTO "medium2substance" VALUES(8,210,NULL,'i-Inositol');
INSERT INTO "medium2substance" VALUES(8,25,NULL,'D-Calcium pantothenate');
INSERT INTO "medium2substance" VALUES(8,211,NULL,'Folic Acid');
INSERT INTO "medium2substance" VALUES(8,26,NULL,'Pyridoxine hydrochloride');
INSERT INTO "medium2substance" VALUES(8,87,NULL,'Vitamin B12');
INSERT INTO "medium2substance" VALUES(8,88,NULL,'Vitamin B12');
INSERT INTO "medium2substance" VALUES(8,285,NULL,'Vitamin B12');
INSERT INTO "medium2substance" VALUES(8,102,NULL,'D-Glucose (Dextrose)');
INSERT INTO "medium2substance" VALUES(8,197,NULL,'Glutathione (reduced)');
INSERT INTO "medium2substance" VALUES(8,286,NULL,'Calcium nitrate (Ca(NO3)2 4H2O)');
INSERT INTO "medium2substance" VALUES(8,120,NULL,'Oxygen');
INSERT INTO "medium2substance" VALUES(8,78,NULL,'Bicarbonate (NaHCO3)');
INSERT INTO "medium2substance" VALUES(8,303,NULL,'L-Hydroxyproline');
INSERT INTO "medium2substance" VALUES(8,76,NULL,'Carbon dioxide');
INSERT INTO "medium2substance" VALUES(8,150,NULL,'L-Cystine 2HCl, L-Lysine hydrochloride, L-Tyrosine disodium salt dihydrate, Pyridoxine hydrochloride, Thiamine hydrochloride');
INSERT INTO "medium2substance" VALUES(2,183,NULL,'Lysine');
INSERT INTO "medium2substance" VALUES(2,178,NULL,'Histidine');
INSERT INTO "medium2substance" VALUES(2,166,NULL,'Arginine');
INSERT INTO "medium2substance" VALUES(2,169,NULL,'Aspartic acid');
INSERT INTO "medium2substance" VALUES(2,192,NULL,'Threonine');
INSERT INTO "medium2substance" VALUES(2,175,NULL,'Glutamic acid');
INSERT INTO "medium2substance" VALUES(2,138,NULL,'Glycine');
INSERT INTO "medium2substance" VALUES(2,196,NULL,'Valine');
INSERT INTO "medium2substance" VALUES(2,186,NULL,'Methionine');
INSERT INTO "medium2substance" VALUES(2,180,NULL,'Isoleucine');
INSERT INTO "medium2substance" VALUES(2,182,NULL,'Leucine');
INSERT INTO "medium2substance" VALUES(2,195,NULL,'Tyrosine');
INSERT INTO "medium2substance" VALUES(2,188,NULL,'L-Phenylalanine');
INSERT INTO "medium2substance" VALUES(3,56,NULL,'(NH4)2SO4');
INSERT INTO "medium2substance" VALUES(3,258,NULL,'(NH4)2SO4, MgSO4.7H2O, FeSO4.7H2O, MnSO4.H2O, CuSO4.5H2O, ZnSO4.7H2O');
INSERT INTO "medium2substance" VALUES(3,235,NULL,'K2HPO4, KH2PO4');
INSERT INTO "medium2substance" VALUES(3,232,NULL,'K2HPO4, KH2PO4');
INSERT INTO "medium2substance" VALUES(3,281,NULL,'Urea');
INSERT INTO "medium2substance" VALUES(3,75,NULL,'CaCl2.2H2O');
INSERT INTO "medium2substance" VALUES(3,81,NULL,'CaCl2.2H2O, NiCl2.6H2O');
INSERT INTO "medium2substance" VALUES(3,201,NULL,'MgSO4.7H2O');
INSERT INTO "medium2substance" VALUES(3,156,NULL,'FeSO4.7H2O');
INSERT INTO "medium2substance" VALUES(3,157,NULL,'FeSO4.7H2O');
INSERT INTO "medium2substance" VALUES(3,204,NULL,'MnSO4.H2O');
INSERT INTO "medium2substance" VALUES(3,214,NULL,'NiCl2.6H2O');
INSERT INTO "medium2substance" VALUES(3,90,NULL,'CuSO4.5H2O');
INSERT INTO "medium2substance" VALUES(3,289,NULL,'ZnSO4.7H2O');
INSERT INTO "medium2substance" VALUES(3,66,NULL,'Biotin');
INSERT INTO "medium2substance" VALUES(3,102,NULL,'D-Glucose');
INSERT INTO "medium2substance" VALUES(3,286,NULL,'CaCl2.2H2O, MgSO4.7H2O, FeSO4.7H2O, MnSO4.H2O, NiCl2.6H2O, CuSO4.5H2O, ZnSO4.7H2O, NaOH');
INSERT INTO "medium2substance" VALUES(3,120,NULL,'Oxygen');
INSERT INTO "medium2substance" VALUES(3,251,NULL,'NaOH');
INSERT INTO "medium2substance" VALUES(3,150,NULL,'K2HPO4, KH2PO4');
INSERT INTO "medium2substance" VALUES(3,19,NULL,'Protocatechuic acid');
INSERT INTO "medium2substance" VALUES(1,1,0.007164,'Erucic acid');
INSERT INTO "medium2substance" VALUES(1,2,0.0260005,'Nervonic acid');
INSERT INTO "medium2substance" VALUES(1,3,2.91e-05,'20a-Dihydroprogesterone');
INSERT INTO "medium2substance" VALUES(1,4,0.0015,'Fumaric acid');
INSERT INTO "medium2substance" VALUES(1,5,0.00019,'D-Limonene');
INSERT INTO "medium2substance" VALUES(1,6,0.105618962173913,'Docosahexaenoic acid');
INSERT INTO "medium2substance" VALUES(1,7,0.00407275,'Adrenic acid');
INSERT INTO "medium2substance" VALUES(1,8,0.0533333333333333,'(R)-3-Hydroxybutyric acid');
INSERT INTO "medium2substance" VALUES(1,9,0.02035,'3-Methyl-2-Oxovaleric Acid');
INSERT INTO "medium2substance" VALUES(1,11,84.57,'Methylimidazoleacetic acid');
INSERT INTO "medium2substance" VALUES(1,10,0.00043,'1-Methylnicotinamide');
INSERT INTO "medium2substance" VALUES(1,12,0.024225,'2-Hydroxybutyric acid');
INSERT INTO "medium2substance" VALUES(1,14,5.5e-06,'Cyclic GMP');
INSERT INTO "medium2substance" VALUES(1,15,7.95e-05,'2-Methylcitric acid');
INSERT INTO "medium2substance" VALUES(1,16,0.1089,'Citric acid');
INSERT INTO "medium2substance" VALUES(1,17,0.00795,'Oxoglutaric acid');
INSERT INTO "medium2substance" VALUES(1,18,1.2475e-05,'25-Hydroxyvitamin D2');
INSERT INTO "medium2substance" VALUES(1,20,6.0e-06,'3,4-Dihydroxyphenylglycol');
INSERT INTO "medium2substance" VALUES(1,21,5.5e-06,'Cyclic GMP');
INSERT INTO "medium2substance" VALUES(1,22,0.00037,'4-Hydroxyphenylpyruvic acid');
INSERT INTO "medium2substance" VALUES(1,23,5.0e-06,'3-Hydroxyhexadecanoylcarnitine');
INSERT INTO "medium2substance" VALUES(1,24,11,'alpha-Ketoisovaleric acid');
INSERT INTO "medium2substance" VALUES(1,25,0.00269,'Pantothenic acid');
INSERT INTO "medium2substance" VALUES(1,270,8.86666666666667e-05,'Thiamine');
INSERT INTO "medium2substance" VALUES(1,26,2.5e-05,'Pyridoxine');
INSERT INTO "medium2substance" VALUES(1,27,0.000164,'Pyridoxamine');
INSERT INTO "medium2substance" VALUES(1,29,0.00011,'gamma-Aminobutyric acid');
INSERT INTO "medium2substance" VALUES(1,30,0.000251,'Pyridoxal');
INSERT INTO "medium2substance" VALUES(1,31,0.000217,'4-Hydroxydebrisoquine');
INSERT INTO "medium2substance" VALUES(1,32,0.0098814444444444,'p-Hydroxyphenylacetic acid');
INSERT INTO "medium2substance" VALUES(1,33,0.0265,'Ketoleucine');
INSERT INTO "medium2substance" VALUES(1,34,20.95,'4-Pyridoxic acid');
INSERT INTO "medium2substance" VALUES(1,35,2.5e-06,'Tetrahydrofolic acid');
INSERT INTO "medium2substance" VALUES(1,36,7.7e-05,'(R)-lipoic acid');
INSERT INTO "medium2substance" VALUES(1,37,0.019075,'Adenosine monophosphate');
INSERT INTO "medium2substance" VALUES(1,38,2.5e-06,'Folinic acid');
INSERT INTO "medium2substance" VALUES(1,39,9.7e-06,'Guanosine monophosphate');
INSERT INTO "medium2substance" VALUES(1,40,1.8e-05,'5-Hydroxy-L-tryptophan');
INSERT INTO "medium2substance" VALUES(1,41,0.0003,'5-Methyltetrahydrofolic acid');
INSERT INTO "medium2substance" VALUES(1,42,0.0195,'Pyroglutamic acid');
INSERT INTO "medium2substance" VALUES(1,43,0.0049,'Phosphoribosyl pyrophosphate');
INSERT INTO "medium2substance" VALUES(1,44,184,'Uridine 5-monophosphate');
INSERT INTO "medium2substance" VALUES(1,45,1.7175e-06,'Dihydrotestosterone');
INSERT INTO "medium2substance" VALUES(1,46,5.0e-06,'Dihydrofolic acid');
INSERT INTO "medium2substance" VALUES(1,47,0.0024199295081967,'Vitamin A');
INSERT INTO "medium2substance" VALUES(1,48,0.16,'ADP');
INSERT INTO "medium2substance" VALUES(1,49,2.03133333333333,'Adenosine triphosphate');
INSERT INTO "medium2substance" VALUES(1,50,1,'Acetaldehyde');
INSERT INTO "medium2substance" VALUES(1,51,0.04206,'Acetic acid');
INSERT INTO "medium2substance" VALUES(1,52,0.0248375,'Acetoacetic acid');
INSERT INTO "medium2substance" VALUES(1,53,0.0537833333333333,'Acetone');
INSERT INTO "medium2substance" VALUES(1,54,0.00047,'Adenine');
INSERT INTO "medium2substance" VALUES(1,55,0.0011670833333333,'Adenosine');
INSERT INTO "medium2substance" VALUES(1,56,27,'Ammonia');
INSERT INTO "medium2substance" VALUES(1,57,6.0325e-05,'Androsterone');
INSERT INTO "medium2substance" VALUES(1,58,0.000437075,'Androsterone glucuronide');
INSERT INTO "medium2substance" VALUES(1,59,1.55e-05,'2-Aminobenzoic acid');
INSERT INTO "medium2substance" VALUES(1,60,0.0072778,'Arachidic acid');
INSERT INTO "medium2substance" VALUES(1,61,0.171059889655172,'Arachidonic acid');
INSERT INTO "medium2substance" VALUES(1,63,0.010951,'Behenic acid');
INSERT INTO "medium2substance" VALUES(1,64,0.020784625,'Benzoic acid');
INSERT INTO "medium2substance" VALUES(1,65,0.0078472857142857,'Bilirubin');
INSERT INTO "medium2substance" VALUES(1,66,37.89,'Biotin');
INSERT INTO "medium2substance" VALUES(1,67,1,'Butyric acid');
INSERT INTO "medium2substance" VALUES(1,68,0.0001995,'Butyrylcarnitine');
INSERT INTO "medium2substance" VALUES(1,69,8.5e-06,'Cyclic AMP');
INSERT INTO "medium2substance" VALUES(1,70,36,'CDP');
INSERT INTO "medium2substance" VALUES(1,73,6.75785714285714e-05,'Calcidiol');
INSERT INTO "medium2substance" VALUES(1,74,4.10333333333333e-05,'Vitamin D3');
INSERT INTO "medium2substance" VALUES(1,75,2.102375,'Calcium');
INSERT INTO "medium2substance" VALUES(1,76,23.05,'Carbon dioxide');
INSERT INTO "medium2substance" VALUES(1,77,72,'Carbon monoxide');
INSERT INTO "medium2substance" VALUES(1,78,23.54,'Hydrogen carbonate');
INSERT INTO "medium2substance" VALUES(1,80,0.001165,'Chenodeoxycholic acid');
INSERT INTO "medium2substance" VALUES(1,81,100.85,'Chloride ion');
INSERT INTO "medium2substance" VALUES(1,82,0.00072,'Cholic acid');
INSERT INTO "medium2substance" VALUES(1,86,2.1793258125,'Cholesterol');
INSERT INTO "medium2substance" VALUES(1,83,0.00932,'Choline');
INSERT INTO "medium2substance" VALUES(1,91,2.7e-05,'Corticosterone');
INSERT INTO "medium2substance" VALUES(1,92,0.0002554285714285,'Cortisol');
INSERT INTO "medium2substance" VALUES(1,93,0.0464842857142857,'Creatine');
INSERT INTO "medium2substance" VALUES(1,95,4.5e-05,'Cyanate');
INSERT INTO "medium2substance" VALUES(1,96,0.0441666666666667,'Cysteinylglycine');
INSERT INTO "medium2substance" VALUES(1,97,0.000175,'Cytidine');
INSERT INTO "medium2substance" VALUES(1,98,0.0064,'Cytosine');
INSERT INTO "medium2substance" VALUES(1,99,0.44675,'D-Alanine');
INSERT INTO "medium2substance" VALUES(1,100,0.0395,'D-Fructose');
INSERT INTO "medium2substance" VALUES(1,101,0.06365,'D-Galactose');
INSERT INTO "medium2substance" VALUES(1,103,0.00913,'D-Lactic acid');
INSERT INTO "medium2substance" VALUES(1,104,0.0515,'D-Mannose');
INSERT INTO "medium2substance" VALUES(1,106,0.0023,'D-Ribose');
INSERT INTO "medium2substance" VALUES(1,107,0.0025866666666666,'D-Serine');
INSERT INTO "medium2substance" VALUES(1,108,0.007045,'Sorbitol');
INSERT INTO "medium2substance" VALUES(1,109,2.4431,'D-Xylose');
INSERT INTO "medium2substance" VALUES(1,110,0.000149,'Debrisoquine');
INSERT INTO "medium2substance" VALUES(1,111,11,'Capric acid');
INSERT INTO "medium2substance" VALUES(1,112,0.0002101666666666,'Decanoylcarnitine');
INSERT INTO "medium2substance" VALUES(1,113,0.005772,'Dehydroascorbic acid');
INSERT INTO "medium2substance" VALUES(1,114,0.0024675,'Dehydroepiandrosterone sulfate');
INSERT INTO "medium2substance" VALUES(1,116,0.00045,'Deoxycholic acid');
INSERT INTO "medium2substance" VALUES(1,117,0.0002,'Deoxycytidine');
INSERT INTO "medium2substance" VALUES(1,118,0.000213,'Deoxyuridine');
INSERT INTO "medium2substance" VALUES(1,119,0.0156,'Dihydroxyacetone phosphate');
INSERT INTO "medium2substance" VALUES(1,120,6.36,'Oxygen');
INSERT INTO "medium2substance" VALUES(1,121,0.0018,'Pyrophosphate');
INSERT INTO "medium2substance" VALUES(1,122,0.00582225,'Dodecanoic acid');
INSERT INTO "medium2substance" VALUES(1,123,2.65e-05,'Dopamine 3-O-sulfate');
INSERT INTO "medium2substance" VALUES(1,124,2.75e-06,'Ergocalciferol');
INSERT INTO "medium2substance" VALUES(1,125,2.32833333333333e-06,'Estrone sulfate');
INSERT INTO "medium2substance" VALUES(1,126,0.0183333333333333,'Ethanol');
INSERT INTO "medium2substance" VALUES(1,127,7.95e-06,'Flavin Mononucleotide');
INSERT INTO "medium2substance" VALUES(1,128,6.8e-05,'FAD');
INSERT INTO "medium2substance" VALUES(1,129,0.0133,'Formaldehyde');
INSERT INTO "medium2substance" VALUES(1,130,0.0868733333333333,'Formic acid');
INSERT INTO "medium2substance" VALUES(1,131,0.0165,'Guanosine diphosphate');
INSERT INTO "medium2substance" VALUES(1,132,56,'Guanosine triphosphate');
INSERT INTO "medium2substance" VALUES(1,133,0.0015,'Tetrahexosylceramide (d18:1/12:0)');
INSERT INTO "medium2substance" VALUES(1,134,0.00029,'Glucosamine');
INSERT INTO "medium2substance" VALUES(1,135,165,'D-Glucuronic acid');
INSERT INTO "medium2substance" VALUES(1,136,0.147266666666667,'Glycerol');
INSERT INTO "medium2substance" VALUES(1,137,0.03,'Glycerol 3-phosphate');
INSERT INTO "medium2substance" VALUES(1,138,0.241736363636364,'Glycine');
INSERT INTO "medium2substance" VALUES(1,139,0.04567,'Betaine');
INSERT INTO "medium2substance" VALUES(1,140,6.0e-05,'Chenodeoxycholic acid glycine conjugate');
INSERT INTO "medium2substance" VALUES(1,141,6.0e-05,'Glycocholic acid');
INSERT INTO "medium2substance" VALUES(1,142,9.0e-06,'Lithocholic acid glycine conjugate');
INSERT INTO "medium2substance" VALUES(1,143,0.00019,'Glycoursodeoxycholic acid');
INSERT INTO "medium2substance" VALUES(1,144,0.0008,'Guanosine');
INSERT INTO "medium2substance" VALUES(1,146,0.00047,'Hexacosanoic acid');
INSERT INTO "medium2substance" VALUES(1,147,0.520931074074074,'Palmitic acid');
INSERT INTO "medium2substance" VALUES(1,148,0.050230695,'Palmitoleic acid');
INSERT INTO "medium2substance" VALUES(1,149,5.3e-05,'Hyaluronic acid');
INSERT INTO "medium2substance" VALUES(1,150,3.98107170553497e-05,'Protons');
INSERT INTO "medium2substance" VALUES(1,151,0.0105,'Hydrogen peroxide');
INSERT INTO "medium2substance" VALUES(1,152,0.0376,'Hydrogen sulfide');
INSERT INTO "medium2substance" VALUES(1,153,0.0059921428571428,'Hypoxanthine');
INSERT INTO "medium2substance" VALUES(1,154,63,'Inosinic acid');
INSERT INTO "medium2substance" VALUES(1,155,0.00129,'Inosine');
INSERT INTO "medium2substance" VALUES(1,156,8922,'Fe2+');
INSERT INTO "medium2substance" VALUES(1,160,0.000138,'Isovaleryl Carnitine');
INSERT INTO "medium2substance" VALUES(1,161,2,'L-Arabitol');
INSERT INTO "medium2substance" VALUES(1,162,0.10118,'L-Cystine');
INSERT INTO "medium2substance" VALUES(1,163,0.00103,'(S)-b-aminoisobutyric acid');
INSERT INTO "medium2substance" VALUES(1,164,0.3847625,'L-Alanine');
INSERT INTO "medium2substance" VALUES(1,165,0.0025,'L-Arabinose');
INSERT INTO "medium2substance" VALUES(1,166,0.09366625,'L-Arginine');
INSERT INTO "medium2substance" VALUES(1,167,0.0361379,'Ascorbic acid');
INSERT INTO "medium2substance" VALUES(1,168,0.0473777777777778,'L-Asparagine');
INSERT INTO "medium2substance" VALUES(1,169,0.015232,'L-Aspartic acid');
INSERT INTO "medium2substance" VALUES(1,170,0.0354711111111111,'L-Carnitine');
INSERT INTO "medium2substance" VALUES(1,171,0.00327,'Carnosine');
INSERT INTO "medium2substance" VALUES(1,172,0.0294222222222222,'Citrulline');
INSERT INTO "medium2substance" VALUES(1,173,0.120988333333333,'L-Cysteine');
INSERT INTO "medium2substance" VALUES(1,174,7.23e-06,'L-Dopa');
INSERT INTO "medium2substance" VALUES(1,175,0.057029,'L-Glutamic acid');
INSERT INTO "medium2substance" VALUES(1,176,0.564136363636364,'L-Glutamine');
INSERT INTO "medium2substance" VALUES(1,177,2,'L-Glyceric acid');
INSERT INTO "medium2substance" VALUES(1,178,0.124895882352941,'L-Histidine');
INSERT INTO "medium2substance" VALUES(1,179,12,'L-Homoserine');
INSERT INTO "medium2substance" VALUES(1,180,0.06335,'L-Isoleucine');
INSERT INTO "medium2substance" VALUES(1,181,1.97934285714286,'L-Lactic acid');
INSERT INTO "medium2substance" VALUES(1,182,0.13608,'L-Leucine');
INSERT INTO "medium2substance" VALUES(1,183,0.191545454545455,'L-Lysine');
INSERT INTO "medium2substance" VALUES(1,184,0.0076,'L-Malic acid');
INSERT INTO "medium2substance" VALUES(1,185,1.6e-06,'Metanephrine');
INSERT INTO "medium2substance" VALUES(1,186,0.486815384615385,'L-Methionine');
INSERT INTO "medium2substance" VALUES(1,188,0.06845,'L-Phenylalanine');
INSERT INTO "medium2substance" VALUES(1,189,0.177728571428571,'L-Proline');
INSERT INTO "medium2substance" VALUES(1,190,0.124866666666667,'L-Serine');
INSERT INTO "medium2substance" VALUES(1,191,0.007045,'Sorbitol');
INSERT INTO "medium2substance" VALUES(1,192,0.140433333333333,'L-Threonine');
INSERT INTO "medium2substance" VALUES(1,193,4.998375e-06,'Thyroxine');
INSERT INTO "medium2substance" VALUES(1,194,0.05829,'L-Tryptophan');
INSERT INTO "medium2substance" VALUES(1,195,0.0752272727272727,'L-Tyrosine');
INSERT INTO "medium2substance" VALUES(1,196,0.216933333333333,'L-Valine');
INSERT INTO "medium2substance" VALUES(1,197,0.17101476,'Glutathione');
INSERT INTO "medium2substance" VALUES(1,199,0.637224432258065,'Linoleic acid');
INSERT INTO "medium2substance" VALUES(1,200,0.00033,'Lithocholic acid');
INSERT INTO "medium2substance" VALUES(1,205,0.266618,'Heptadecanoic acid');
INSERT INTO "medium2substance" VALUES(1,208,0.163525,'Methanol');
INSERT INTO "medium2substance" VALUES(1,209,0.055295,'Pyruvaldehyde');
INSERT INTO "medium2substance" VALUES(1,210,0.023525,'myo-Inositol');
INSERT INTO "medium2substance" VALUES(1,211,2.33333333333333e-05,'Folic acid');
INSERT INTO "medium2substance" VALUES(1,212,0.00334,'Alpha-N-Phenylacetyl-L-glutamine');
INSERT INTO "medium2substance" VALUES(1,213,0.000235,'Niacinamide');
INSERT INTO "medium2substance" VALUES(1,215,0.0243,'NAD');
INSERT INTO "medium2substance" VALUES(1,216,0.0196,'NADP');
INSERT INTO "medium2substance" VALUES(1,218,0.0242925,'Nitrite');
INSERT INTO "medium2substance" VALUES(1,220,2.8125e-06,'Norepinephrine');
INSERT INTO "medium2substance" VALUES(1,221,8.0e-06,'Norepinephrine sulfate');
INSERT INTO "medium2substance" VALUES(1,222,0.2860335535,'Stearic acid');
INSERT INTO "medium2substance" VALUES(1,223,0.29180212,'Oleic acid');
INSERT INTO "medium2substance" VALUES(1,224,0.00525,'Caprylic acid');
INSERT INTO "medium2substance" VALUES(1,225,0.0001801666666666,'L-Octanoylcarnitine');
INSERT INTO "medium2substance" VALUES(1,226,0.0002,'2-Octenoylcarnitine');
INSERT INTO "medium2substance" VALUES(1,227,0.1,'Elaidic acid');
INSERT INTO "medium2substance" VALUES(1,105,61,'Ornithine');
INSERT INTO "medium2substance" VALUES(1,187,61,'Ornithine');
INSERT INTO "medium2substance" VALUES(1,228,0.002945,'Orotic acid');
INSERT INTO "medium2substance" VALUES(1,229,0.01029,'Oxalic acid');
INSERT INTO "medium2substance" VALUES(1,230,0.010825,'Oxidized glutathione');
INSERT INTO "medium2substance" VALUES(1,231,0.100780833333333,'Pentadecanoic acid');
INSERT INTO "medium2substance" VALUES(1,232,0.73955,'Phosphate');
INSERT INTO "medium2substance" VALUES(1,233,1.535,'Vitamin K1');
INSERT INTO "medium2substance" VALUES(1,234,0.00301,'Phytanic acid');
INSERT INTO "medium2substance" VALUES(1,235,3.65714285714286,'Potassium');
INSERT INTO "medium2substance" VALUES(1,236,4.1172e-05,'Progesterone');
INSERT INTO "medium2substance" VALUES(1,237,0.0009,'Propionic acid');
INSERT INTO "medium2substance" VALUES(1,239,0.000108,'Putrescine');
INSERT INTO "medium2substance" VALUES(1,240,0.05115,'Nicotinic acid');
INSERT INTO "medium2substance" VALUES(1,241,2.86760888888889e-05,'Pyridoxal 5-phosphate');
INSERT INTO "medium2substance" VALUES(1,242,0.0553125,'Pyruvic acid');
INSERT INTO "medium2substance" VALUES(1,243,0.00010725,'All-trans-retinoic acid');
INSERT INTO "medium2substance" VALUES(1,244,6.6e-06,'Retinoyl b-glucuronide');
INSERT INTO "medium2substance" VALUES(1,245,0.00046,'Ribitol');
INSERT INTO "medium2substance" VALUES(1,246,0.000215,'Riboflavin');
INSERT INTO "medium2substance" VALUES(1,247,0.0004666666666666,'Sarcosine');
INSERT INTO "medium2substance" VALUES(1,250,0.000654,'Serotonin');
INSERT INTO "medium2substance" VALUES(1,251,137.533333333333,'Sodium');
INSERT INTO "medium2substance" VALUES(1,252,0.0047425,'Spermidine');
INSERT INTO "medium2substance" VALUES(1,253,0.0033833333333333,'Spermine');
INSERT INTO "medium2substance" VALUES(1,254,5.5e-05,'Sphinganine 1-phosphate');
INSERT INTO "medium2substance" VALUES(1,255,0.000278,'Sphingosine 1-phosphate');
INSERT INTO "medium2substance" VALUES(1,256,0.0136,'Succinic acid');
INSERT INTO "medium2substance" VALUES(1,257,0.0018,'Sucrose');
INSERT INTO "medium2substance" VALUES(1,258,0.35275,'Sulfate');
INSERT INTO "medium2substance" VALUES(1,259,0.00123,'Sulfite');
INSERT INTO "medium2substance" VALUES(1,260,6.0e-05,'Sulfolithocholylglycine');
INSERT INTO "medium2substance" VALUES(1,261,0.0870909090909091,'Taurine');
INSERT INTO "medium2substance" VALUES(1,262,0.0003,'Taurochenodesoxycholic acid');
INSERT INTO "medium2substance" VALUES(1,263,0.00038,'Taurocholic acid');
INSERT INTO "medium2substance" VALUES(1,264,6.2e-05,'Taurodeoxycholic acid');
INSERT INTO "medium2substance" VALUES(1,265,0.001212,'Lithocholyltaurine');
INSERT INTO "medium2substance" VALUES(1,266,7.275,'Testosterone');
INSERT INTO "medium2substance" VALUES(1,267,0.0059583333333333,'Tetracosanoic acid');
INSERT INTO "medium2substance" VALUES(1,268,0.0226672857142857,'Myristic acid');
INSERT INTO "medium2substance" VALUES(1,271,0.03183,'Thiocyanate');
INSERT INTO "medium2substance" VALUES(1,272,0.05115,'Thiosulfate');
INSERT INTO "medium2substance" VALUES(1,273,0.0001472121,'Thromboxane B2');
INSERT INTO "medium2substance" VALUES(1,274,0.0001366666666666,'Thymidine');
INSERT INTO "medium2substance" VALUES(1,276,41,'Uridine 5-diphosphate');
INSERT INTO "medium2substance" VALUES(1,277,155,'Uridine diphosphate glucose');
INSERT INTO "medium2substance" VALUES(1,278,3.12e-06,'Ubiquinone-10');
INSERT INTO "medium2substance" VALUES(1,279,0.001135,'Uracil');
INSERT INTO "medium2substance" VALUES(1,280,0.2632195625,'Uric acid');
INSERT INTO "medium2substance" VALUES(1,281,4.72292,'Urea');
INSERT INTO "medium2substance" VALUES(1,282,0.0091066666666666,'Uridine');
INSERT INTO "medium2substance" VALUES(1,283,0.00016,'Ursodeoxycholic acid');
INSERT INTO "medium2substance" VALUES(1,286,55000,'Water');
INSERT INTO "medium2substance" VALUES(1,287,2.2e-05,'Xanthurenic acid');
INSERT INTO "medium2substance" VALUES(1,288,0.000677,'D-Xylitol');
INSERT INTO "medium2substance" VALUES(1,290,0.143446279130435,'Eicosapentaenoic acid');
INSERT INTO "medium2substance" VALUES(1,291,7.0e-06,'Cis-8,11,14,17-Eicosatetraenoic acid');
INSERT INTO "medium2substance" VALUES(1,292,0.0466641666666667,'8,11,14-Eicosatrienoic acid');
INSERT INTO "medium2substance" VALUES(1,293,0.000212,'Stearidonic acid');
INSERT INTO "medium2substance" VALUES(1,294,0.000155,'Retinal');
INSERT INTO "medium2substance" VALUES(1,295,0.0024199295081967,'Vitamin A');
INSERT INTO "medium2substance" VALUES(1,296,0.0286517555555556,'Alpha-Linolenic acid');
INSERT INTO "medium2substance" VALUES(1,297,0.0338456388235294,'Alpha-Tocopherol');
INSERT INTO "medium2substance" VALUES(1,298,0.00423,'Alpha-Tocotrienol');
INSERT INTO "medium2substance" VALUES(1,299,0.002635,'beta-Alanine');
INSERT INTO "medium2substance" VALUES(1,300,0.0382245952380952,'B-Carotene');
INSERT INTO "medium2substance" VALUES(1,301,0.0002,'Beta-tocopherol');
INSERT INTO "medium2substance" VALUES(1,302,0.01213,'Gamma-Linolenic acid');
INSERT INTO "medium2substance" VALUES(1,304,0.0986,'Vaccenic acid');
INSERT INTO "medium2substance" VALUES(7,251,NULL,'Na2SO4, Na3C6H5O7.2H2O, NaCl, NaH2PO4.2H2O, Na2HPO4.2H2O');
INSERT INTO "medium2substance" VALUES(7,81,NULL,'KCl, NaCl, CaCl2, NH4Cl');
INSERT INTO "medium2substance" VALUES(7,258,NULL,'Na2SO4, MgSO4.7H2O');
INSERT INTO "medium2substance" VALUES(7,280,NULL,'C5H4N4O3');
INSERT INTO "medium2substance" VALUES(7,16,NULL,'Na3C6H5O7.2H2O');
INSERT INTO "medium2substance" VALUES(7,94,NULL,'C4H7N3O');
INSERT INTO "medium2substance" VALUES(7,281,NULL,'CH4N2O');
INSERT INTO "medium2substance" VALUES(7,235,NULL,'KCl, K2C2O4.H2O');
INSERT INTO "medium2substance" VALUES(7,75,NULL,'CaCl2');
INSERT INTO "medium2substance" VALUES(7,56,NULL,'NH4Cl');
INSERT INTO "medium2substance" VALUES(7,229,NULL,'K2C2O4.H2O');
INSERT INTO "medium2substance" VALUES(7,201,NULL,'MgSO4.7H2O');
INSERT INTO "medium2substance" VALUES(7,150,NULL,'NaH2PO4.2H2O, Na2HPO4.2H2O');
INSERT INTO "medium2substance" VALUES(7,232,NULL,'NaH2PO4.2H2O, Na2HPO4.2H2O');
INSERT INTO "medium2substance" VALUES(7,286,NULL,'Na3C6H5O7.2H2O, K2C2O4.H2O, MgSO4.7H2O, NaH2PO4.2H2O, Na2HPO4.2H2O');
INSERT INTO "medium2substance" VALUES(7,120,NULL,'Oxygen');
INSERT INTO "medium2substance" VALUES(4,102,NULL,'D-Glucose');
INSERT INTO "medium2substance" VALUES(4,100,NULL,'Fructose');
INSERT INTO "medium2substance" VALUES(4,79,NULL,'Cellobiose');
INSERT INTO "medium2substance" VALUES(4,203,NULL,'Maltose');
INSERT INTO "medium2substance" VALUES(4,145,NULL,'Hematin');
INSERT INTO "medium2substance" VALUES(4,178,NULL,'L-Histidine');
INSERT INTO "medium2substance" VALUES(4,173,NULL,'L-Cysteine');
INSERT INTO "medium2substance" VALUES(4,156,NULL,'FeSO4.7H2O');
INSERT INTO "medium2substance" VALUES(4,157,NULL,'FeSO4.7H2O');
INSERT INTO "medium2substance" VALUES(4,258,NULL,'FeSO4.7H2O, ZnSO4*7H2O, AlK(SO4)2 (anhydrous), CuSO4 (anhydrous), MnSO4*H2O, MgSO4*7H2O');
INSERT INTO "medium2substance" VALUES(4,286,NULL,'FeSO4.7H2O, ZnSO4*7H2O, Co(NO3)2.6H2O, Na2WO4.2H2O, NiCl2.6H2O, MgSO4*7H2O, Na2MoO4.2H2O');
INSERT INTO "medium2substance" VALUES(4,289,NULL,'ZnSO4*7H2O');
INSERT INTO "medium2substance" VALUES(4,89,NULL,'Co(NO3)2.6H2O');
INSERT INTO "medium2substance" VALUES(4,217,NULL,'Co(NO3)2.6H2O');
INSERT INTO "medium2substance" VALUES(4,235,NULL,'AlK(SO4)2 (anhydrous), KH2PO4');
INSERT INTO "medium2substance" VALUES(4,251,NULL,'Na2SeO3 (anhydrous), Na2WO4.2H2O, NaCl, NaHCO3, Na2MoO4.2H2O');
INSERT INTO "medium2substance" VALUES(4,81,NULL,'NiCl2.6H2O, CaCl2 (anhydrous), NaCl, Thiamine HCl, Pyridoxine HCl');
INSERT INTO "medium2substance" VALUES(4,248,NULL,'Na2SeO3 (anhydrous)');
INSERT INTO "medium2substance" VALUES(4,275,NULL,'Na2WO4.2H2O');
INSERT INTO "medium2substance" VALUES(4,214,NULL,'NiCl2.6H2O');
INSERT INTO "medium2substance" VALUES(4,75,NULL,'CaCl2 (anhydrous), Calcium Pantothenate');
INSERT INTO "medium2substance" VALUES(4,90,NULL,'CuSO4 (anhydrous)');
INSERT INTO "medium2substance" VALUES(4,204,NULL,'MnSO4*H2O');
INSERT INTO "medium2substance" VALUES(4,201,NULL,'MgSO4*7H2O');
INSERT INTO "medium2substance" VALUES(4,78,NULL,'NaHCO3');
INSERT INTO "medium2substance" VALUES(4,269,NULL,'Na2MoO4.2H2O');
INSERT INTO "medium2substance" VALUES(4,66,NULL,'Biotin');
INSERT INTO "medium2substance" VALUES(4,270,NULL,'Thiamine HCl');
INSERT INTO "medium2substance" VALUES(4,246,NULL,'Riboflavin');
INSERT INTO "medium2substance" VALUES(4,240,NULL,'Niacin');
INSERT INTO "medium2substance" VALUES(4,26,NULL,'Pyridoxine HCl');
INSERT INTO "medium2substance" VALUES(4,25,NULL,'Calcium Pantothenate');
INSERT INTO "medium2substance" VALUES(4,211,NULL,'Folic acid');
INSERT INTO "medium2substance" VALUES(4,28,NULL,'p-Aminobenzoic acid');
INSERT INTO "medium2substance" VALUES(4,36,NULL,'Lipoic acid');
INSERT INTO "medium2substance" VALUES(4,285,NULL,'Vitamin B12');
INSERT INTO "medium2substance" VALUES(4,87,NULL,'Vitamin B12');
INSERT INTO "medium2substance" VALUES(4,88,NULL,'Vitamin B12');
INSERT INTO "medium2substance" VALUES(4,206,NULL,'Vitamin K (menadione)');
INSERT INTO "medium2substance" VALUES(4,51,NULL,'Acetic acid');
INSERT INTO "medium2substance" VALUES(4,159,NULL,'Isovaleric acid');
INSERT INTO "medium2substance" VALUES(4,237,NULL,'Propionic acid');
INSERT INTO "medium2substance" VALUES(4,67,NULL,'Butyric acid');
INSERT INTO "medium2substance" VALUES(4,150,NULL,'Thiamine HCl, Pyridoxine HCl, KH2PO4');
INSERT INTO "medium2substance" VALUES(4,232,NULL,'KH2PO4');
INSERT INTO "medium2substance" VALUES(4,76,NULL,'Carbon dioxide (From gas mix)');
INSERT INTO "medium2substance" VALUES(4,219,NULL,'Nitrogen (From gas mix)');
INSERT INTO "medium2substance" VALUES(2,164,NULL,'Alanine');
INSERT INTO "medium2substance" VALUES(2,189,NULL,'Proline');
INSERT INTO "medium2substance" VALUES(2,190,NULL,'Serine');
INSERT INTO "medium2substance" VALUES(2,56,NULL,'Ammonia');
INSERT INTO "medium2substance" VALUES(2,223,NULL,'Oleic acid');
INSERT INTO "medium2substance" VALUES(2,222,NULL,'Stearic acid');
INSERT INTO "medium2substance" VALUES(2,305,NULL,'Cysteic acid');
INSERT INTO "medium2substance" VALUES(3,306,NULL,'NaOH');
INSERT INTO "medium2substance" VALUES(4,307,NULL,'Hydrogen (From gas mix)');
INSERT INTO "medium2substance" VALUES(4,308,NULL,'AlK(SO4)2 (anhydrous)');
INSERT INTO "medium2substance" VALUES(10,251,NULL,'Sodium chloride, Sodium pyruvate, Monosodium phosphate');
INSERT INTO "medium2substance" VALUES(10,81,NULL,'Sodium chloride, L-Lysine HCl, L-Ornithine HCl');
INSERT INTO "medium2substance" VALUES(10,242,NULL,'Sodium pyruvate');
INSERT INTO "medium2substance" VALUES(10,232,NULL,'Monosodium phosphate');
INSERT INTO "medium2substance" VALUES(10,150,NULL,'Monosodium phosphate, Potassium H carbonate, L-Lysine HCl, L-Ornithine HCl');
INSERT INTO "medium2substance" VALUES(10,75,NULL,'Calcium sulfate dihydrate');
INSERT INTO "medium2substance" VALUES(10,258,NULL,'Calcium sulfate dihydrate');
INSERT INTO "medium2substance" VALUES(10,286,NULL,'Calcium sulfate dihydrate');
INSERT INTO "medium2substance" VALUES(10,235,NULL,'Potassium H carbonate');
INSERT INTO "medium2substance" VALUES(10,78,NULL,'Potassium H carbonate');
INSERT INTO "medium2substance" VALUES(10,102,NULL,'D-Glucose');
INSERT INTO "medium2substance" VALUES(10,138,NULL,'Glycine');
INSERT INTO "medium2substance" VALUES(10,182,NULL,'L-Leucine');
INSERT INTO "medium2substance" VALUES(10,190,NULL,'L-Serine');
INSERT INTO "medium2substance" VALUES(10,164,NULL,'L-Alanine');
INSERT INTO "medium2substance" VALUES(10,166,NULL,'L-Arginine');
INSERT INTO "medium2substance" VALUES(10,178,NULL,'L-Histidine');
INSERT INTO "medium2substance" VALUES(10,196,NULL,'L-Valine');
INSERT INTO "medium2substance" VALUES(10,180,NULL,'L-Isoleucine');
INSERT INTO "medium2substance" VALUES(10,183,NULL,'L-Lysine HCl');
INSERT INTO "medium2substance" VALUES(10,188,NULL,'L-Phenylalanine');
INSERT INTO "medium2substance" VALUES(10,195,NULL,'L-Tyrosine');
INSERT INTO "medium2substance" VALUES(10,176,NULL,'L-Glutamine');
INSERT INTO "medium2substance" VALUES(10,169,NULL,'L-Aspartic acid');
INSERT INTO "medium2substance" VALUES(10,175,NULL,'L-Glutamic acid');
INSERT INTO "medium2substance" VALUES(10,189,NULL,'L-Proline');
INSERT INTO "medium2substance" VALUES(10,187,NULL,'L-Ornithine HCl');
INSERT INTO "medium2substance" VALUES(10,172,NULL,'L-Citrulline');
INSERT INTO "medium2substance" VALUES(10,194,NULL,'L-Tryptophan');
INSERT INTO "medium2substance" VALUES(10,168,NULL,'L-Asparagine');
INSERT INTO "medium2substance" VALUES(10,192,NULL,'L-Threonine');
INSERT INTO "medium2substance" VALUES(11,56,NULL,'From M9: NH4Cl');
INSERT INTO "medium2substance" VALUES(11,89,NULL,'Cobalt Chloride hexahydrate');
INSERT INTO "medium2substance" VALUES(11,81,NULL,'Cobalt Chloride hexahydrate, Calcium Chloride anhydrous, Thiamine HCl; From M9: NaCl, NH4Cl');
INSERT INTO "medium2substance" VALUES(11,286,NULL,'Cobalt Chloride hexahydrate, Magnesium Sulfate heptahydrate');
INSERT INTO "medium2substance" VALUES(11,75,NULL,'Calcium Chloride anhydrous, Calcium pantothenate');
INSERT INTO "medium2substance" VALUES(11,201,NULL,'Magnesium Sulfate heptahydrate');
INSERT INTO "medium2substance" VALUES(11,258,NULL,'Magnesium Sulfate heptahydrate');
INSERT INTO "medium2substance" VALUES(11,102,NULL,'Glucose');
INSERT INTO "medium2substance" VALUES(11,120,NULL,'Oxygen');
INSERT INTO "medium2substance" VALUES(11,150,NULL,'Thiamine HCl, From M9: KH2PO4, Na2HPO4');
INSERT INTO "medium2substance" VALUES(11,232,NULL,'From M9: KH2PO4, Na2HPO4');
INSERT INTO "medium2substance" VALUES(11,235,NULL,'From M9: KH2PO4');
INSERT INTO "medium2substance" VALUES(11,251,NULL,'From M9: NaCl, Na2HPO4');
INSERT INTO "medium2substance" VALUES(11,166,NULL,'L-Arginine');
INSERT INTO "medium2substance" VALUES(11,189,NULL,'L-Proline');
INSERT INTO "medium2substance" VALUES(11,270,NULL,'Thiamine HCl');
INSERT INTO "medium2substance" VALUES(11,66,NULL,'Biotin');
INSERT INTO "medium2substance" VALUES(11,240,NULL,'Nicotinic acid');
INSERT INTO "medium2substance" VALUES(11,25,NULL,'Calcium pantothenate');
INSERT INTO "medium2substance" VALUES(5,314,NULL,'Selenium');
INSERT INTO "medium2substance" VALUES(5,315,NULL,'Selenium');
INSERT INTO "medium2substance" VALUES(5,316,NULL,'Selenium');
INSERT INTO "medium2substance" VALUES(5,248,NULL,'Selenium');


CREATE TABLE IF NOT EXISTS "subset" (
	id INTEGER PRIMARY KEY,
	name TEXT NOT NULL UNIQUE,
	description NTEXT NOT NULL
);
INSERT INTO "subset" VALUES(1,'CasA','Casamino acids (based on: https://www.usbio.net/media/C2080/casamino-acids#:~:text=Casamino%2520Acids%2520is%2520a%2520hydrochloric,destroyed%2520by%2520the%2520acid%2520treatment)');
INSERT INTO "subset" VALUES(2,'protAA','Proteinogenic amino acids');
INSERT INTO "subset" VALUES(3,'artSe','Artificial Sebum (based on: https://journals.asm.org/doi/10.1128/spectrum.04180-22, Table 2)');
INSERT INTO "subset" VALUES(4,'DiReM','Dissociation reaction metabolites');


CREATE TABLE IF NOT EXISTS "subset2substance" (
	subset_id INTEGER,
	substance_id INTEGER,
	percent NUMERIC DEFAULT 1.0,
	FOREIGN KEY(subset_id) REFERENCES subset(id),
	FOREIGN KEY(substance_id) REFERENCES substance(id),
	PRIMARY KEY(subset_id, substance_id)
);
INSERT INTO "subset2substance" VALUES(1,164,0.028);
INSERT INTO "subset2substance" VALUES(1,166,0.036);
INSERT INTO "subset2substance" VALUES(1,169,0.063);
INSERT INTO "subset2substance" VALUES(1,162,0.003);
INSERT INTO "subset2substance" VALUES(1,175,0.211);
INSERT INTO "subset2substance" VALUES(1,138,0.022);
INSERT INTO "subset2substance" VALUES(1,178,0.027);
INSERT INTO "subset2substance" VALUES(1,180,0.056);
INSERT INTO "subset2substance" VALUES(1,182,0.084);
INSERT INTO "subset2substance" VALUES(1,183,0.075);
INSERT INTO "subset2substance" VALUES(1,186,0.027);
INSERT INTO "subset2substance" VALUES(1,188,0.046);
INSERT INTO "subset2substance" VALUES(1,189,0.099);
INSERT INTO "subset2substance" VALUES(1,190,0.056);
INSERT INTO "subset2substance" VALUES(1,192,0.042);
INSERT INTO "subset2substance" VALUES(1,194,0.011);
INSERT INTO "subset2substance" VALUES(1,195,0.061);
INSERT INTO "subset2substance" VALUES(1,196,0.05);
INSERT INTO "subset2substance" VALUES(2,164,1);
INSERT INTO "subset2substance" VALUES(2,166,1);
INSERT INTO "subset2substance" VALUES(2,168,1);
INSERT INTO "subset2substance" VALUES(2,169,1);
INSERT INTO "subset2substance" VALUES(2,173,1);
INSERT INTO "subset2substance" VALUES(2,175,1);
INSERT INTO "subset2substance" VALUES(2,176,1);
INSERT INTO "subset2substance" VALUES(2,138,1);
INSERT INTO "subset2substance" VALUES(2,178,1);
INSERT INTO "subset2substance" VALUES(2,180,1);
INSERT INTO "subset2substance" VALUES(2,182,1);
INSERT INTO "subset2substance" VALUES(2,183,1);
INSERT INTO "subset2substance" VALUES(2,186,1);
INSERT INTO "subset2substance" VALUES(2,188,1);
INSERT INTO "subset2substance" VALUES(2,189,1);
INSERT INTO "subset2substance" VALUES(2,190,1);
INSERT INTO "subset2substance" VALUES(2,192,1);
INSERT INTO "subset2substance" VALUES(2,194,1);
INSERT INTO "subset2substance" VALUES(2,195,1);
INSERT INTO "subset2substance" VALUES(2,196,1);
INSERT INTO "subset2substance" VALUES(3,309,0.15);
INSERT INTO "subset2substance" VALUES(3,86,0.012);
INSERT INTO "subset2substance" VALUES(3,310,0.024);
INSERT INTO "subset2substance" VALUES(3,311,0.15);
INSERT INTO "subset2substance" VALUES(3,223,0.26003118);
INSERT INTO "subset2substance" VALUES(3,268,0.06488692);
INSERT INTO "subset2substance" VALUES(3,122,0.11967712);
INSERT INTO "subset2substance" VALUES(3,147,0.21487992);
INSERT INTO "subset2substance" VALUES(3,111,0.01327186);
INSERT INTO "subset2substance" VALUES(3,205,6.368e-05);
INSERT INTO "subset2substance" VALUES(3,222,0.02062044);
INSERT INTO "subset2substance" VALUES(3,60,0.00094698);
INSERT INTO "subset2substance" VALUES(3,63,0.00027534);
INSERT INTO "subset2substance" VALUES(3,267,5.298e-05);
INSERT INTO "subset2substance" VALUES(3,148,0.00711788);
INSERT INTO "subset2substance" VALUES(3,312,0.00068406);
INSERT INTO "subset2substance" VALUES(3,199,0.29159666);
INSERT INTO "subset2substance" VALUES(3,75,1.536e-05);
INSERT INTO "subset2substance" VALUES(3,156,2.18e-06);
INSERT INTO "subset2substance" VALUES(3,157,2.18e-06);
INSERT INTO "subset2substance" VALUES(3,286,0.0004337);
INSERT INTO "subset2substance" VALUES(3,83,4.08e-06);
INSERT INTO "subset2substance" VALUES(3,297,0.000175);
INSERT INTO "subset2substance" VALUES(3,233,7.8e-07);
INSERT INTO "subset2substance" VALUES(3,235,8.46e-06);
INSERT INTO "subset2substance" VALUES(3,251,2.734e-05);
INSERT INTO "subset2substance" VALUES(3,67,3.442e-05);
INSERT INTO "subset2substance" VALUES(3,224,0.01862542);
INSERT INTO "subset2substance" VALUES(3,231,3.078e-05);
INSERT INTO "subset2substance" VALUES(3,289,1.0e-07);
INSERT INTO "subset2substance" VALUES(3,296,3.758e-05);
INSERT INTO "subset2substance" VALUES(3,61,0.00049758);
INSERT INTO "subset2substance" VALUES(4,286,1);
INSERT INTO "subset2substance" VALUES(4,49,1);
INSERT INTO "subset2substance" VALUES(4,150,1);
INSERT INTO "subset2substance" VALUES(4,232,1);
INSERT INTO "subset2substance" VALUES(4,70,1);
INSERT INTO "subset2substance" VALUES(4,318,1);
INSERT INTO "subset2substance" VALUES(4,132,1);
INSERT INTO "subset2substance" VALUES(4,131,1);
INSERT INTO "subset2substance" VALUES(4,319,1);
INSERT INTO "subset2substance" VALUES(4,276,1);
INSERT INTO "subset2substance" VALUES(4,320,1);
INSERT INTO "subset2substance" VALUES(4,321,1);
INSERT INTO "subset2substance" VALUES(4,215,1);
INSERT INTO "subset2substance" VALUES(4,322,1);
INSERT INTO "subset2substance" VALUES(4,216,1);
INSERT INTO "subset2substance" VALUES(4,323,1);
INSERT INTO "subset2substance" VALUES(4,128,1);
INSERT INTO "subset2substance" VALUES(4,324,1);
INSERT INTO "subset2substance" VALUES(4,127,1);
INSERT INTO "subset2substance" VALUES(4,325,1);
INSERT INTO "subset2substance" VALUES(4,326,1);
INSERT INTO "subset2substance" VALUES(4,327,1);
INSERT INTO "subset2substance" VALUES(4,329,1);
INSERT INTO "subset2substance" VALUES(4,328,1);
INSERT INTO "subset2substance" VALUES(4,331,1);
INSERT INTO "subset2substance" VALUES(4,330,1);
INSERT INTO "subset2substance" VALUES(4,332,1);
INSERT INTO "subset2substance" VALUES(4,51,1);
INSERT INTO "subset2substance" VALUES(4,334,1);
INSERT INTO "subset2substance" VALUES(4,102,1);
INSERT INTO "subset2substance" VALUES(4,17,1);
INSERT INTO "subset2substance" VALUES(4,56,1);
INSERT INTO "subset2substance" VALUES(4,48,1);


CREATE TABLE IF NOT EXISTS substance (
	id INTEGER PRIMARY KEY,
	name NTEXT NOT NULL UNIQUE,
	formula TEXT
);
INSERT INTO "substance" VALUES(1,'(13Z)-13-Docosenoic acid [Erucic acid]','C22H42O2');
INSERT INTO "substance" VALUES(2,'(15Z)-Tetracosenoate [Nervonate]','C24H45O2');
INSERT INTO "substance" VALUES(3,'(20S)-20-Hydroxypregn-4-en-3-one [20alpha-Hydroxyprogesterone]','C21H32O2');
INSERT INTO "substance" VALUES(4,'(2E)-But-2-enedioate [Fumarate]','C4H2O4');
INSERT INTO "substance" VALUES(5,'(4R)-1-Methyl-4-(prop-1-en-2-yl)cyclohex-1-ene [D-Limonene]','C10H16');
INSERT INTO "substance" VALUES(6,'(4Z,7Z,10Z,13Z,16Z,19Z)-Docosahexaenoate [Cervonic acid]','C22H31O2');
INSERT INTO "substance" VALUES(7,'(7Z,10Z,13Z,16Z)-Docosatetraenoate [Adrenic acid]','C22H35O2');
INSERT INTO "substance" VALUES(8,'(R)-3-Hydroxybutanoate [(R)-3-Hydroxybutyric acid]','C4H7O3');
INSERT INTO "substance" VALUES(9,'(S)-3-Methyl-2-oxopentanoate [3-Methyl-2-Oxovaleric acid]','C6H9O3');
INSERT INTO "substance" VALUES(10,'1-Methylnicotinamide','C7H9N2O');
INSERT INTO "substance" VALUES(11,'1-Methyl-4-imidazoleacetic acid','C6H8N2O2');
INSERT INTO "substance" VALUES(12,'2 Hydroxybutyrate [2-Hydroxybutyric acid]','C4H8O3');
INSERT INTO "substance" VALUES(13,'2,2-Bipyridine','C10H8N2');
INSERT INTO "substance" VALUES(14,'2,3-Cyclic GMP [Cyclic GMP]','C10H12N5O7P');
INSERT INTO "substance" VALUES(15,'2-Methylcitrate [2-Methylcitric acid]','C7H7O7');
INSERT INTO "substance" VALUES(16,'2-Oxidopropane-1,2,3-tricarboxylate [Citrate]','C6H4O7');
INSERT INTO "substance" VALUES(17,'2-Oxoglutarate [Oxoglutaric acid]','C5H4O5');
INSERT INTO "substance" VALUES(18,'25-Hydroxyvitamin D2','C28H44O2');
INSERT INTO "substance" VALUES(19,'3,4-Dihydroxybenzoate','C7H5O4');
INSERT INTO "substance" VALUES(20,'3,4-Dihydroxyphenylethyleneglycol [3,4-Dihydroxyphenylglycol]','C8H10O4');
INSERT INTO "substance" VALUES(21,'3,5-Cyclic GMP [Cyclic GMP]','C10H12N5O7P');
INSERT INTO "substance" VALUES(22,'3-(4-Hydroxyphenyl)pyruvate [4-Hydroxyphenylpyruvic acid]','C9H7O4');
INSERT INTO "substance" VALUES(23,'3-Hydroxyhexadecanoylcarnithine','C23H45NO5');
INSERT INTO "substance" VALUES(24,'3-Methyl-2-oxobutanoate [alpha-Ketoisovaleric acid]','C5H7O3');
INSERT INTO "substance" VALUES(25,'3-[(2R)-2,4-Dihydroxy-3,3-dimethylbutanamido]propanoate [Pantothenate]','C9H16NO5');
INSERT INTO "substance" VALUES(26,'4,5-Bis(hydroxymethyl)-2-methylpyridin-3-ol [Pyridoxine]','C8H11NO3');
INSERT INTO "substance" VALUES(27,'4-(Azaniumylmethyl)-3-hydroxy-5-(hydroxymethyl)-2-methylpyridin-1-ium [Pyridoxamine]','C8H14N2O2');
INSERT INTO "substance" VALUES(28,'4-Aminobenzoic acid','C7H7NO2');
INSERT INTO "substance" VALUES(29,'4-Aminobutanoate [gamma-Aminobutyric acid]','C4H8NO2');
INSERT INTO "substance" VALUES(30,'4-Formyl-3-hydroxy-5-(hydroxymethyl)-2-methylpyridin-1-ium [Pyridoxal]','C8H10NO3');
INSERT INTO "substance" VALUES(31,'4-Hydroxydebrisoquin','C10H13N3O');
INSERT INTO "substance" VALUES(32,'4-Hydroxyphenylacetate [p-Hydroxyphenylacetic acid]','C8H8O3');
INSERT INTO "substance" VALUES(33,'4-Methyl-2-oxopentanoate [Ketoleucine]','C6H9O3');
INSERT INTO "substance" VALUES(34,'4-Pyridoxate','C8H8NO4');
INSERT INTO "substance" VALUES(35,'5,6,7,8-Tetrahydrofolate [Tetrahydrofolic acid]','C19H23N7O6');
INSERT INTO "substance" VALUES(36,'5-(1,2-Dithiolan-3-yl)pentanoate [Lipoate]','C8H13O2S2');
INSERT INTO "substance" VALUES(37,'5-Adenylic acid [AMP]','C10H14N5O7P');
INSERT INTO "substance" VALUES(38,'5-Formyltetrahydrofolate','C20H21N7O7');
INSERT INTO "substance" VALUES(39,'5-Guanylic acid [GMP]','C10H14N5O8P');
INSERT INTO "substance" VALUES(40,'5-Hydroxy-L-tryptophan','C11H12N2O3');
INSERT INTO "substance" VALUES(41,'5-Methyltetrahydrofolate [5-Methyltetrahydrofolic acid]','C20H25N7O6');
INSERT INTO "substance" VALUES(42,'5-Oxoproline [Pyroglutamic acid]','C5H7NO3');
INSERT INTO "substance" VALUES(43,'5-Phospho-alpha-D-ribose 1-diphosphate [Phosphoribosyl pyrophosphate]','C5H13O14P3');
INSERT INTO "substance" VALUES(44,'5-Uridylic acid [UMP]','C9H13N2O9P');
INSERT INTO "substance" VALUES(45,'5-beta-Dihydrotestosterone','C19H28O2');
INSERT INTO "substance" VALUES(46,'7,8-Dihydrofolate [Dihydrofolic acid]','C19H21N7O6');
INSERT INTO "substance" VALUES(47,'9-cis-Retinol','C20H30O');
INSERT INTO "substance" VALUES(48,'ADP [Adenosine diphosphate]','C10H15N5O10P2');
INSERT INTO "substance" VALUES(49,'ATP [Adenosine triphosphate]','C10H16N5O13P3');
INSERT INTO "substance" VALUES(50,'Acetaldehyde','C2H4O');
INSERT INTO "substance" VALUES(51,'Acetate [Acetic acid]','C2H3O2');
INSERT INTO "substance" VALUES(52,'Acetoacetate [Acetoacetic acid]','C4H6O3');
INSERT INTO "substance" VALUES(53,'Acetone','C3H6O');
INSERT INTO "substance" VALUES(54,'Adenine','C5H5N5');
INSERT INTO "substance" VALUES(55,'Adenosine','C10H13N5O4');
INSERT INTO "substance" VALUES(56,'Ammonia','H3N');
INSERT INTO "substance" VALUES(57,'Androsterone','C19H30O2');
INSERT INTO "substance" VALUES(58,'Androsterone 3-glucosiduronic acid','C25H38O8');
INSERT INTO "substance" VALUES(59,'Anthranilate [2-Aminobenzoic acid]','C7H6NO2');
INSERT INTO "substance" VALUES(60,'Arachidic acid','C20H40O2');
INSERT INTO "substance" VALUES(61,'Arachidonate','C20H31O2');
INSERT INTO "substance" VALUES(62,'Arsenite','AsO3');
INSERT INTO "substance" VALUES(63,'Behenate [Docosanoate]','C22H43O2');
INSERT INTO "substance" VALUES(64,'Benzoate [Benzoic acid]','C7H5O2');
INSERT INTO "substance" VALUES(65,'Billirubin','C33H36N4O6');
INSERT INTO "substance" VALUES(66,'Biotin','C10H15N2O3S');
INSERT INTO "substance" VALUES(67,'Butyrate','C4H7O2');
INSERT INTO "substance" VALUES(68,'Butyryl carnitine','C11H21NO4');
INSERT INTO "substance" VALUES(69,'CAMP [Cyclic AMP]','C10H12N5O6P');
INSERT INTO "substance" VALUES(70,'CDP [Cytidine diphosphate]','C9H15N3O11P2');
INSERT INTO "substance" VALUES(71,'CMP','C9H14N3O8P');
INSERT INTO "substance" VALUES(72,'Cadmium(II) cation [Cd2+]','Cd');
INSERT INTO "substance" VALUES(73,'Calcidiol [25-Hydroxyvitamin D3]','C27H44O2');
INSERT INTO "substance" VALUES(74,'Calciol [Vitamin D3]','C27H44O');
INSERT INTO "substance" VALUES(75,'Calcium(II) cation [Ca(2+)]','Ca');
INSERT INTO "substance" VALUES(76,'Carbon dioxide [CO2]','CO2');
INSERT INTO "substance" VALUES(77,'Carbon monoxide','CO');
INSERT INTO "substance" VALUES(78,'Hydrogencarbonate','CHO3');
INSERT INTO "substance" VALUES(79,'Cellobiose','C12H22O11');
INSERT INTO "substance" VALUES(80,'Chenodeoxycholate [Chenodeoxycholic acid]','C24H39O4');
INSERT INTO "substance" VALUES(81,'Chloride [Cl(-)]','Cl');
INSERT INTO "substance" VALUES(82,'Cholate [Cholic acid]','C24H39O5');
INSERT INTO "substance" VALUES(83,'Choline','C5H14NO');
INSERT INTO "substance" VALUES(84,'Chorismate','C10H8O6');
INSERT INTO "substance" VALUES(85,'Chromate','CrO4');
INSERT INTO "substance" VALUES(86,'Cholesterol','C27H46O');
INSERT INTO "substance" VALUES(87,'Cob(I)alamin','C62H89CoN13O14P');
INSERT INTO "substance" VALUES(88,'Cob(II)alamin','C62H88CoN13O14P');
INSERT INTO "substance" VALUES(89,'Cobalt(II) cation [Co(2+)]','Co');
INSERT INTO "substance" VALUES(90,'Copper(II) cation [Cu(2+)]','Cu');
INSERT INTO "substance" VALUES(91,'Corticosterone','C21H30O4');
INSERT INTO "substance" VALUES(92,'Cortisol','C21H30O5');
INSERT INTO "substance" VALUES(93,'Creatine','C4H9N3O2');
INSERT INTO "substance" VALUES(94,'Creatinine','C4H7N3O');
INSERT INTO "substance" VALUES(95,'Cyanate','CNO');
INSERT INTO "substance" VALUES(96,'Cys Gly [Cysteinylglycine]','C5H10N2O3S');
INSERT INTO "substance" VALUES(97,'Cytidine','C9H13N3O5');
INSERT INTO "substance" VALUES(98,'Cytosine','C4H5N3O');
INSERT INTO "substance" VALUES(99,'D-Alanine','C3H7NO2');
INSERT INTO "substance" VALUES(100,'D-Fructose','C6H12O6');
INSERT INTO "substance" VALUES(101,'D-Galactose','C6H12O6');
INSERT INTO "substance" VALUES(102,'D-Glucose','C6H12O6');
INSERT INTO "substance" VALUES(103,'D-Lactate [D-Lactic acid]','C3H5O3');
INSERT INTO "substance" VALUES(104,'D-Mannose','C6H12O6');
INSERT INTO "substance" VALUES(105,'D-Ornithine','C5H12N2O2');
INSERT INTO "substance" VALUES(106,'D-Ribose','C5H10O5');
INSERT INTO "substance" VALUES(107,'D-Serine','C3H7NO3');
INSERT INTO "substance" VALUES(108,'D-Sorbitol [Sorbitol]','C6H14O6');
INSERT INTO "substance" VALUES(109,'D-Xylose','C5H10O5');
INSERT INTO "substance" VALUES(110,'Debrisoquine','C10H13N3');
INSERT INTO "substance" VALUES(111,'Decanoate','C10H19O2');
INSERT INTO "substance" VALUES(112,'Decanoyl carnitine','C17H33NO4');
INSERT INTO "substance" VALUES(113,'Dehydroascorbate [Dehydroascorbic acid]','C6H6O6');
INSERT INTO "substance" VALUES(114,'Dehydroepiandrosterone sulfate','C19H28O5S');
INSERT INTO "substance" VALUES(115,'Deoxyadenosine','C10H13N5O3');
INSERT INTO "substance" VALUES(116,'Deoxycholate [Deoxycholic acid]','C24H40O4');
INSERT INTO "substance" VALUES(117,'Deoxycytidine','C9H13N3O4');
INSERT INTO "substance" VALUES(118,'Deoxyuridine','C9H12N2O5');
INSERT INTO "substance" VALUES(119,'Dihydroxyacetone phosphate','C3H7O6P');
INSERT INTO "substance" VALUES(120,'Dioxygen [O2]','O2');
INSERT INTO "substance" VALUES(121,'Diphosphate [Pyrophosphate]','O7P2');
INSERT INTO "substance" VALUES(122,'Dodecanoate','C12H23O2');
INSERT INTO "substance" VALUES(123,'Dopamine 3-O-sulfate','C8H11NO5S');
INSERT INTO "substance" VALUES(124,'Ergocalciferol [Vitamin D2]','C28H44O');
INSERT INTO "substance" VALUES(125,'Estrone 3-sulfate','C18H21O5S');
INSERT INTO "substance" VALUES(126,'Ethanol','C2H6O');
INSERT INTO "substance" VALUES(127,'FMN [oxidized Flavin mononucleotide]','C17H21N4O9P');
INSERT INTO "substance" VALUES(128,'FAD [oxidized Flavin adenine dinucleotide]','C27H33N9O15P2');
INSERT INTO "substance" VALUES(129,'Formaldehyde','CH2O');
INSERT INTO "substance" VALUES(130,'Formate [Formic acid]','CHO2');
INSERT INTO "substance" VALUES(131,'GDP [Guanosine diphosphate]','C10H15N5O11P2');
INSERT INTO "substance" VALUES(132,'GTP [Guanosine triphosphate]','C10H16N5O14P3');
INSERT INTO "substance" VALUES(133,'Globoside',NULL);
INSERT INTO "substance" VALUES(134,'Glucosamine','C6H13NO5');
INSERT INTO "substance" VALUES(135,'Glucuronate [D-Glucuronic acid]','C6H9O7');
INSERT INTO "substance" VALUES(136,'Glycerol','C3H8O3');
INSERT INTO "substance" VALUES(137,'Glycerol 3-phosphate','C3H9O6P');
INSERT INTO "substance" VALUES(138,'Glycine','C2H5NO2');
INSERT INTO "substance" VALUES(139,'Glycine betaine [Betaine]','C5H12NO2');
INSERT INTO "substance" VALUES(140,'Glycochenodeoxycholate','C26H42NO5');
INSERT INTO "substance" VALUES(141,'Glycocholate','C26H42NO6');
INSERT INTO "substance" VALUES(142,'Glycolithocolate [Lithocholic acid glycine conjugate]','C26H43NO4');
INSERT INTO "substance" VALUES(143,'Glycoursodeoxycholate [Glycoursodeoxycholic acid]','C26H42NO5');
INSERT INTO "substance" VALUES(144,'Guanosine','C10H13N5O5');
INSERT INTO "substance" VALUES(145,'HemeD','C34H32FeN4O6');
INSERT INTO "substance" VALUES(146,'Hexacosanoate','C26H51O2');
INSERT INTO "substance" VALUES(147,'Hexadecanoate [Palmitic acid]','C16H32O2');
INSERT INTO "substance" VALUES(148,'Hexadecenoate','C16H29O2');
INSERT INTO "substance" VALUES(149,'Hyaluronate beta1','C28H40N2O22');
INSERT INTO "substance" VALUES(150,'Hydrogen [H(+)]','H');
INSERT INTO "substance" VALUES(151,'Hydrogen peroxide','H2O2');
INSERT INTO "substance" VALUES(152,'Hydrogen sulfide','H2S');
INSERT INTO "substance" VALUES(153,'Hypoxanthine','C5H4N4O');
INSERT INTO "substance" VALUES(154,'IMP [Inosinic acid]','C10H13N4O8P');
INSERT INTO "substance" VALUES(155,'Inosine','C10H12N4O5');
INSERT INTO "substance" VALUES(156,'Iron(II) cation [Fe(2+)]','Fe');
INSERT INTO "substance" VALUES(157,'Iron(III) cation [Fe(3+)]','Fe');
INSERT INTO "substance" VALUES(158,'Isobutyrate','C4H7O2');
INSERT INTO "substance" VALUES(159,'Isovalerate','C5H9O2');
INSERT INTO "substance" VALUES(160,'Isovaleryl carnitine','C12H23NO4');
INSERT INTO "substance" VALUES(161,'L Arabinitol [L-Arabitol]','C5H12O5');
INSERT INTO "substance" VALUES(162,'L-Cystine','C6H12N2O4S2');
INSERT INTO "substance" VALUES(163,'L-3-Amino-isobutanoate [(S)-b-Aminoisobutyric acid]','C4H9NO2');
INSERT INTO "substance" VALUES(164,'L-Alanine','C3H7NO2');
INSERT INTO "substance" VALUES(165,'L-Arabinose','C5H10O5');
INSERT INTO "substance" VALUES(166,'L-Arginine','C6H14N4O2');
INSERT INTO "substance" VALUES(167,'L-Ascorbate [Ascorbic acid]','C6H7O6');
INSERT INTO "substance" VALUES(168,'L-Asparagine','C4H8N2O3');
INSERT INTO "substance" VALUES(169,'L-Aspartate','C4H6NO4');
INSERT INTO "substance" VALUES(170,'L-Carnitine','C7H15NO3');
INSERT INTO "substance" VALUES(171,'L-Carnosine','C9H14N4O3');
INSERT INTO "substance" VALUES(172,'L-Citrulline [Citrulline]','C6H13N3O3');
INSERT INTO "substance" VALUES(173,'L-Cysteine','C3H7NO2S');
INSERT INTO "substance" VALUES(174,'L-Dopa [3,4-Dihydroxy-L-phenylalanine]','C9H11NO4');
INSERT INTO "substance" VALUES(175,'L-Glutamate','C5H8NO4');
INSERT INTO "substance" VALUES(176,'L-Glutamine','C5H10N2O3');
INSERT INTO "substance" VALUES(177,'L-Glycerate','C3H5O4');
INSERT INTO "substance" VALUES(178,'L-Histidine','C6H9N3O2');
INSERT INTO "substance" VALUES(179,'L-Homoserine','C4H9NO3');
INSERT INTO "substance" VALUES(180,'L-Isoleucine','C6H13NO2');
INSERT INTO "substance" VALUES(181,'L-Lactate [L-Lactic acid]','C3H5O3');
INSERT INTO "substance" VALUES(182,'L-Leucine','C6H13NO2');
INSERT INTO "substance" VALUES(183,'L-Lysine','C6H14N2O2');
INSERT INTO "substance" VALUES(184,'L-Malate [L-Malic acid]','C4H4O5');
INSERT INTO "substance" VALUES(185,'L-Metanephrine','C10H15NO3');
INSERT INTO "substance" VALUES(186,'L-Methionine','C5H11NO2S');
INSERT INTO "substance" VALUES(187,'L-Ornithine','C5H12N2O2');
INSERT INTO "substance" VALUES(188,'L-Phenylalanine','C9H11NO2');
INSERT INTO "substance" VALUES(189,'L-Proline','C5H9NO2');
INSERT INTO "substance" VALUES(190,'L-Serine','C3H7NO3');
INSERT INTO "substance" VALUES(191,'L-Sorbitol [Sorbitol]','C6H14O6');
INSERT INTO "substance" VALUES(192,'L-Threonine','C4H9NO3');
INSERT INTO "substance" VALUES(193,'L-Thyroxine','C15H11I4NO4');
INSERT INTO "substance" VALUES(194,'L-Tryptophan','C11H12N2O2');
INSERT INTO "substance" VALUES(195,'L-Tyrosine','C9H11NO3');
INSERT INTO "substance" VALUES(196,'L-Valine','C5H11NO2');
INSERT INTO "substance" VALUES(197,'L-gamma-Glutamyl-L-cysteinylglycine [Glutathione]','C10H17N3O6S');
INSERT INTO "substance" VALUES(198,'Lead(II) cation [Pb(2+)]','Pb');
INSERT INTO "substance" VALUES(199,'Linoleic acid','C18H31O2');
INSERT INTO "substance" VALUES(200,'Lithocholate [Lithocholic acid]','C24H39O3');
INSERT INTO "substance" VALUES(201,'Magnesium(II) cation [Mg(2+)]','Mg');
INSERT INTO "substance" VALUES(202,'Maleate','C4H3O4');
INSERT INTO "substance" VALUES(203,'Maltose','C12H22O11');
INSERT INTO "substance" VALUES(204,'Manganese(II) cation [Mn(2+)]','Mn');
INSERT INTO "substance" VALUES(205,'Margarate [Heptadecanoate]','C17H33O2');
INSERT INTO "substance" VALUES(206,'Menadione [Vitamin K]','C11H8O2');
INSERT INTO "substance" VALUES(207,'Mercury(II) cation [Hg(2+)]','Hg');
INSERT INTO "substance" VALUES(208,'Methanol','CH4O');
INSERT INTO "substance" VALUES(209,'Methylglyoxal [Pyruvaldehyde]','C3H4O2');
INSERT INTO "substance" VALUES(210,'Myo-inositol','C6H12O6');
INSERT INTO "substance" VALUES(211,'N-(4-{[(2-amino-4-oxo-3,4-dihydropteridin-6-yl)methyl]amino}benzoyl)-L-glutamic acid [Folate]','C19H19N7O6');
INSERT INTO "substance" VALUES(212,'N2-phenylacetyl-L-glutaminate','C13H15N2O4');
INSERT INTO "substance" VALUES(213,'Niacinamide','C6H6N2O');
INSERT INTO "substance" VALUES(214,'Nickel(II) cation [Ni(2+)]','Ni');
INSERT INTO "substance" VALUES(215,'NAD [oxidized Nicotinamide adenine dinucleotide]','C21H27N7O14P2');
INSERT INTO "substance" VALUES(216,'NADP [oxidized Nicotinamide adenine dinucleotide phosphate]','C21H28N7O17P3');
INSERT INTO "substance" VALUES(217,'Nitrate [NO3(-)]','NO3');
INSERT INTO "substance" VALUES(218,'Nitrite','NO2');
INSERT INTO "substance" VALUES(219,'Nitrogen','N2');
INSERT INTO "substance" VALUES(220,'Norepinephrine','C8H11NO3');
INSERT INTO "substance" VALUES(221,'Norepinephrine sulfate','C8H11NO6S');
INSERT INTO "substance" VALUES(222,'Octadecanoate [Stearic acid]','C18H35O2');
INSERT INTO "substance" VALUES(223,'Octadecenoate [Oleic acid]','C18H34O2');
INSERT INTO "substance" VALUES(224,'Octanoate [Caprylic acid]','C8H15O2');
INSERT INTO "substance" VALUES(225,'Octanoyl carnitine [L-Octanoylcarnitine]','C15H29NO4');
INSERT INTO "substance" VALUES(226,'Octenoyl carnitine','C15H27NO4');
INSERT INTO "substance" VALUES(227,'Oleate','C18H33O2');
INSERT INTO "substance" VALUES(228,'Orotate [Orotic acid]','C5H3N2O4');
INSERT INTO "substance" VALUES(229,'Oxalate','C2HO4');
INSERT INTO "substance" VALUES(230,'Oxidized glutathione','C20H32N6O12S2');
INSERT INTO "substance" VALUES(231,'Pentadecanoate','C15H29O2');
INSERT INTO "substance" VALUES(232,'Phosphate [PO4(3-)]','O4P');
INSERT INTO "substance" VALUES(233,'Phylloquinone [Vitamin K1]','C31H46O2');
INSERT INTO "substance" VALUES(234,'Phytanate','C20H39O2');
INSERT INTO "substance" VALUES(235,'Potassium(I) cation [K(+)]','K');
INSERT INTO "substance" VALUES(236,'Progesterone','C21H30O2');
INSERT INTO "substance" VALUES(237,'Propionate','C3H5O2');
INSERT INTO "substance" VALUES(238,'Protoheme','C34H32FeN4O4');
INSERT INTO "substance" VALUES(239,'Putrescine','C4H12N2');
INSERT INTO "substance" VALUES(240,'Pyridine-3-carboxylate [Niacin]','C6H4NO2');
INSERT INTO "substance" VALUES(241,'Pyridoxal 5-phosphate','C8H10NO6P');
INSERT INTO "substance" VALUES(242,'Pyruvate [Pyruvic acid]','C3H3O3');
INSERT INTO "substance" VALUES(243,'Retinoate [all-trans-Retinoic acid]','C20H27O2');
INSERT INTO "substance" VALUES(244,'Retinoyl glucuronide','C26H35O8');
INSERT INTO "substance" VALUES(245,'Ribitol','C5H12O5');
INSERT INTO "substance" VALUES(246,'Riboflavin','C17H20N4O6');
INSERT INTO "substance" VALUES(247,'Sarcosine','C3H7NO2');
INSERT INTO "substance" VALUES(248,'Selenite [SeO3 (2-)]','O3Se');
INSERT INTO "substance" VALUES(250,'Serotonin','C10H12N2O');
INSERT INTO "substance" VALUES(251,'Sodium(I) cation [Na(+)]','Na');
INSERT INTO "substance" VALUES(252,'Spermidine','C7H19N3');
INSERT INTO "substance" VALUES(253,'Spermine','C10H26N4');
INSERT INTO "substance" VALUES(254,'Sphinganine 1-phosphate','C18H39NO5P');
INSERT INTO "substance" VALUES(255,'Sphingosine 1-phosphate','C18H37NO5P');
INSERT INTO "substance" VALUES(256,'Succinate [Succinic acid]','C4H2D4O4');
INSERT INTO "substance" VALUES(257,'Sucrose','C12H22O11');
INSERT INTO "substance" VALUES(258,'Sulfate [SO4(2-)]','O4S');
INSERT INTO "substance" VALUES(259,'Sulfite','HO3S');
INSERT INTO "substance" VALUES(260,'Sulfoglycolithocholate','C26H41NO7S');
INSERT INTO "substance" VALUES(261,'Taurine','C2H7NO3S');
INSERT INTO "substance" VALUES(262,'Taurochenodeoxycholate [Taurochenodesoxycholic acid]','C26H45NO6S');
INSERT INTO "substance" VALUES(263,'Taurocholic acid','C26H45NO7S');
INSERT INTO "substance" VALUES(264,'Taurodeoxycholate [Taurodeoxycholic acid]','C26H44NO6S');
INSERT INTO "substance" VALUES(265,'Taurolithocholate [Lithocholyltaurine]','C26H44NO5S');
INSERT INTO "substance" VALUES(266,'Testosterone','C19H28O2');
INSERT INTO "substance" VALUES(267,'Tetracosanoate [Lignocerate]','C24H47O2');
INSERT INTO "substance" VALUES(268,'Tetradecanoate','C14H27O2');
INSERT INTO "substance" VALUES(269,'Tetraoxidomolybdate(VI) [Molybdate]','MoO4');
INSERT INTO "substance" VALUES(270,'Thiamine','C12H17N4OS');
INSERT INTO "substance" VALUES(271,'Thiocyanate','CNS');
INSERT INTO "substance" VALUES(272,'Thiosulfate','O3S2');
INSERT INTO "substance" VALUES(273,'Thromboxane-b2 [Thromboxane B2]','C20H34O6');
INSERT INTO "substance" VALUES(274,'Thymidine','C10H14N2O5');
INSERT INTO "substance" VALUES(275,'Tungstate','O4W');
INSERT INTO "substance" VALUES(276,'UDP [Uridine diphosphate]','C9H14N2O12P2');
INSERT INTO "substance" VALUES(277,'UDPglucose [Uridine diphosphate glucose]','C15H24N2O17P2');
INSERT INTO "substance" VALUES(278,'Ubiquinone-10','C59H90O4');
INSERT INTO "substance" VALUES(279,'Uracil','C4H4N2O2');
INSERT INTO "substance" VALUES(280,'Urate','C5H3N4O3');
INSERT INTO "substance" VALUES(281,'Urea','CH4N2O');
INSERT INTO "substance" VALUES(282,'Uridine','C9H12N2O6');
INSERT INTO "substance" VALUES(283,'Ursodeoxycholate [Ursodeoxycholic acid]','C24H39O4');
INSERT INTO "substance" VALUES(284,'Valeric acid','C5H10O2');
INSERT INTO "substance" VALUES(285,'Vitamin B12',NULL);
INSERT INTO "substance" VALUES(286,'Water [H2O]','H2O');
INSERT INTO "substance" VALUES(287,'Xanthurenic acid','C10H7NO4');
INSERT INTO "substance" VALUES(288,'Xylitol [D-Xylitol]','C5H12O5');
INSERT INTO "substance" VALUES(289,'Zinc(II) cation [Zn(2+)]','Zn');
INSERT INTO "substance" VALUES(290,'all-cis-5,8,11,14,17-Icosapentaenoate','C20H29O2');
INSERT INTO "substance" VALUES(291,'all-cis-8,11,14,17-Icosatetraenoic acid [ETA]','C20H32O2');
INSERT INTO "substance" VALUES(292,'all-cis-Icosa-8,11,14-trienoic acid [Dihomo-gamma-linolenic acid]','C20H34O2');
INSERT INTO "substance" VALUES(293,'all-cis-Octadeca-6,9,12,15-tetraenoic acid [Stearidonic acid]','C18H33O2');
INSERT INTO "substance" VALUES(294,'all-trans-Retinal [Retinal]','C20H28O');
INSERT INTO "substance" VALUES(295,'all-trans-Retinol [Vitamin A]','C20H30O');
INSERT INTO "substance" VALUES(296,'alpha-Linolenate','C18H29O2');
INSERT INTO "substance" VALUES(297,'alpha-Tocopherol','C29H50O2');
INSERT INTO "substance" VALUES(298,'alpha-Tocotrienol','C29H44O2');
INSERT INTO "substance" VALUES(299,'beta-Alanine','C3H7NO2');
INSERT INTO "substance" VALUES(300,'beta-Carotene [b-Carotene]','C40H56');
INSERT INTO "substance" VALUES(301,'beta-Tocopherol','C28H48O2');
INSERT INTO "substance" VALUES(302,'gamma-Linolenate','C18H29O2');
INSERT INTO "substance" VALUES(303,'trans-4-Hydroxy-L-proline','C5H9NO3');
INSERT INTO "substance" VALUES(304,'trans-Vaccenic acid','C18H34O2');
INSERT INTO "substance" VALUES(305,'L-Cysteate','C3H6NO5S');
INSERT INTO "substance" VALUES(306,'Hydroxide','HO');
INSERT INTO "substance" VALUES(307,'Dihydrogen [H2]','H2');
INSERT INTO "substance" VALUES(308,'Aluminium(III) cation [Al(3+)]','Al');
INSERT INTO "substance" VALUES(309,'Squalene','C30H50');
INSERT INTO "substance" VALUES(310,'Cholesteryl oleate','C45H78O2');
INSERT INTO "substance" VALUES(311,'Hexadecyl palmitate','C32H64O2');
INSERT INTO "substance" VALUES(312,'(11Z)-icos-11-enoate [Gondoate]','C20H37O2');
INSERT INTO "substance" VALUES(314,'L-Selenomethionine','C5H11NO2Se');
INSERT INTO "substance" VALUES(315,'gamma-Glutamyl-Se-methylselenocysteine','C9H16N2O5Se');
INSERT INTO "substance" VALUES(316,'L-Adenosylselenohomocysteine','C14H20N6O5Se');
INSERT INTO "substance" VALUES(317,'Superoxide [O2(-)]','O2');
INSERT INTO "substance" VALUES(318,'CTP [Cytidine triphosphate]','C9H16N3O14P3');
INSERT INTO "substance" VALUES(319,'UTP [Uridine triphosphate]','C9H15N2O15P3');
INSERT INTO "substance" VALUES(320,'ITP [Inosine triphosphate]','C10H15N4O14P3');
INSERT INTO "substance" VALUES(321,'IDP [Inosine diphosphate]','C10H14N4O11P2');
INSERT INTO "substance" VALUES(322,'NADH [reduced Nicotinamide adenine dinucleotide]','C21H29N7O14P2');
INSERT INTO "substance" VALUES(323,'NADPH [reduced Nicotinamide adenine dinucleotide phosphate]','C21H30N7O17P3');
INSERT INTO "substance" VALUES(324,'FADH2 [reduced Flavin adenine dinucleotide]','C27H35N9O15P2');
INSERT INTO "substance" VALUES(325,'FMNH2 [reduced Flavin mononucleotide]','C17H23N4O9P');
INSERT INTO "substance" VALUES(326,'Ubiquinone-8','C49H74O4');
INSERT INTO "substance" VALUES(327,'Ubiquinol-8','C49H76O4');
INSERT INTO "substance" VALUES(328,'Menaquinone-8','C51H72O2');
INSERT INTO "substance" VALUES(329,'Menaquinol-8','C51H74O2');
INSERT INTO "substance" VALUES(330,'2-Demethylmenaquinol-8','C50H72O2');
INSERT INTO "substance" VALUES(331,'2-Demethylmenaquinone-8','C50H70O2');
INSERT INTO "substance" VALUES(332,'Acetyl-CoA','C23H38N7O17P3S');
INSERT INTO "substance" VALUES(334,'Coenzyme A','C21H36N7O16P3S');


CREATE TABLE IF NOT EXISTS substance2db (
	substance_id INTEGER,
	db_id TEXT NOT NULL,
	db_type TEXT NOT NULL,
	FOREIGN KEY(substance_id) REFERENCES substance(id),
	PRIMARY KEY(substance_id, db_id)
);
INSERT INTO "substance2db" VALUES(1,'doco13ac','BiGG');
INSERT INTO "substance2db" VALUES(2,'nrvnc','BiGG');
INSERT INTO "substance2db" VALUES(2,'MNXM91251','MetaNetX');
INSERT INTO "substance2db" VALUES(3,'aprgstrn','BiGG');
INSERT INTO "substance2db" VALUES(3,'MNXM163756','MetaNetX');
INSERT INTO "substance2db" VALUES(4,'fum','BiGG+VMH');
INSERT INTO "substance2db" VALUES(5,'limnen','BiGG');
INSERT INTO "substance2db" VALUES(6,'crvnc','BiGG');
INSERT INTO "substance2db" VALUES(6,'MNXM7161','MetaNetX');
INSERT INTO "substance2db" VALUES(7,'adrn','BiGG');
INSERT INTO "substance2db" VALUES(7,'MNXM40344','MetaNetX');
INSERT INTO "substance2db" VALUES(8,'bhb','BiGG');
INSERT INTO "substance2db" VALUES(9,'3mop','BiGG');
INSERT INTO "substance2db" VALUES(10,'1mncam','BiGG');
INSERT INTO "substance2db" VALUES(11,'3mlda','BiGG');
INSERT INTO "substance2db" VALUES(11,'MNXM91418','MetaNetX');
INSERT INTO "substance2db" VALUES(12,'2hb','BiGG');
INSERT INTO "substance2db" VALUES(14,'23cgmp','BiGG');
INSERT INTO "substance2db" VALUES(13,'cpd25442','SEED');
INSERT INTO "substance2db" VALUES(13,'MNXM34308','MetaNetX');
INSERT INTO "substance2db" VALUES(15,'2mcit','BiGG');
INSERT INTO "substance2db" VALUES(16,'cit','BiGG+VMH');
INSERT INTO "substance2db" VALUES(17,'akg','BiGG');
INSERT INTO "substance2db" VALUES(18,'25hvitd2','BiGG');
INSERT INTO "substance2db" VALUES(18,'MNXM4976','MetaNetX');
INSERT INTO "substance2db" VALUES(19,'34dhbz','BiGG');
INSERT INTO "substance2db" VALUES(20,'34dhoxpeg','BiGG');
INSERT INTO "substance2db" VALUES(21,'35cgmp','BiGG');
INSERT INTO "substance2db" VALUES(22,'34hpp','BiGG');
INSERT INTO "substance2db" VALUES(23,'3hexdcrn','BiGG');
INSERT INTO "substance2db" VALUES(24,'3mob','BiGG');
INSERT INTO "substance2db" VALUES(25,'pnto__R','BiGG');
INSERT INTO "substance2db" VALUES(270,'thm','BiGG+VMH');
INSERT INTO "substance2db" VALUES(26,'pydxn','BiGG');
INSERT INTO "substance2db" VALUES(27,'pydam','BiGG+VMH');
INSERT INTO "substance2db" VALUES(28,'4abz','BiGG+VMH');
INSERT INTO "substance2db" VALUES(29,'4abut','BiGG');
INSERT INTO "substance2db" VALUES(30,'pydx','BiGG');
INSERT INTO "substance2db" VALUES(31,'4hdebrisoquine','BiGG');
INSERT INTO "substance2db" VALUES(31,'MNXM10135','MetaNetX');
INSERT INTO "substance2db" VALUES(32,'4hphac','BiGG');
INSERT INTO "substance2db" VALUES(33,'4mop','BiGG');
INSERT INTO "substance2db" VALUES(34,'4pyrdx','BiGG');
INSERT INTO "substance2db" VALUES(34,'MNXM163205','MetaNetX');
INSERT INTO "substance2db" VALUES(35,'thf','BiGG');
INSERT INTO "substance2db" VALUES(36,'lipoate','BiGG');
INSERT INTO "substance2db" VALUES(36,'lipt','BiGG');
INSERT INTO "substance2db" VALUES(37,'amp','BiGG');
INSERT INTO "substance2db" VALUES(38,'5fothf','BiGG');
INSERT INTO "substance2db" VALUES(38,'5fthf','BiGG');
INSERT INTO "substance2db" VALUES(39,'gmp','BiGG');
INSERT INTO "substance2db" VALUES(40,'5htrp','BiGG');
INSERT INTO "substance2db" VALUES(40,'MNXM162909','MetaNetX');
INSERT INTO "substance2db" VALUES(41,'5mthf','BiGG');
INSERT INTO "substance2db" VALUES(42,'5oxpro','BiGG');
INSERT INTO "substance2db" VALUES(43,'prpp','BiGG');
INSERT INTO "substance2db" VALUES(44,'ump','BiGG');
INSERT INTO "substance2db" VALUES(45,'5adtststerone','BiGG');
INSERT INTO "substance2db" VALUES(45,'MNXM162520','MetaNetX');
INSERT INTO "substance2db" VALUES(46,'dhf','BiGG');
INSERT INTO "substance2db" VALUES(47,'retinol_9_cis','BiGG');
INSERT INTO "substance2db" VALUES(47,'MNXM162711','MetaNetX');
INSERT INTO "substance2db" VALUES(48,'adp','BiGG');
INSERT INTO "substance2db" VALUES(49,'atp','BiGG');
INSERT INTO "substance2db" VALUES(50,'acald','BiGG');
INSERT INTO "substance2db" VALUES(51,'ac','BiGG+VMH');
INSERT INTO "substance2db" VALUES(52,'acac','BiGG');
INSERT INTO "substance2db" VALUES(53,'acetone','BiGG');
INSERT INTO "substance2db" VALUES(54,'ade','BiGG');
INSERT INTO "substance2db" VALUES(55,'adn','BiGG');
INSERT INTO "substance2db" VALUES(56,'nh3','BiGG');
INSERT INTO "substance2db" VALUES(56,'nh4','BiGG');
INSERT INTO "substance2db" VALUES(57,'andrstrn','BiGG');
INSERT INTO "substance2db" VALUES(57,'MNXM162746','MetaNetX');
INSERT INTO "substance2db" VALUES(58,'andrstrnglc','BiGG');
INSERT INTO "substance2db" VALUES(58,'MNXM7068','MetaNetX');
INSERT INTO "substance2db" VALUES(59,'anth','BiGG');
INSERT INTO "substance2db" VALUES(60,'arach','BiGG');
INSERT INTO "substance2db" VALUES(61,'arachd','BiGG');
INSERT INTO "substance2db" VALUES(61,'MNXM162250','MetaNetX');
INSERT INTO "substance2db" VALUES(62,'aso3','BiGG');
INSERT INTO "substance2db" VALUES(63,'docosac','BiGG');
INSERT INTO "substance2db" VALUES(63,'MNXM162817','MetaNetX');
INSERT INTO "substance2db" VALUES(64,'bz','BiGG');
INSERT INTO "substance2db" VALUES(65,'bilirub','BiGG');
INSERT INTO "substance2db" VALUES(66,'btn','BiGG+VMH');
INSERT INTO "substance2db" VALUES(67,'but','BiGG');
INSERT INTO "substance2db" VALUES(67,'MNXM162281','MetaNetX');
INSERT INTO "substance2db" VALUES(68,'c4crn','BiGG');
INSERT INTO "substance2db" VALUES(69,'camp','BiGG');
INSERT INTO "substance2db" VALUES(70,'cdp','BiGG');
INSERT INTO "substance2db" VALUES(71,'cmp','BiGG');
INSERT INTO "substance2db" VALUES(72,'cd2','BiGG');
INSERT INTO "substance2db" VALUES(73,'25hvitd3','BiGG');
INSERT INTO "substance2db" VALUES(73,'MNXM162388','MetaNetX');
INSERT INTO "substance2db" VALUES(74,'vitd3','BiGG');
INSERT INTO "substance2db" VALUES(74,'MNXM162562','MetaNetX');
INSERT INTO "substance2db" VALUES(75,'ca2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(76,'co2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(77,'co','BiGG');
INSERT INTO "substance2db" VALUES(78,'hco3','BiGG+VMH');
INSERT INTO "substance2db" VALUES(79,'cellb','BiGG');
INSERT INTO "substance2db" VALUES(80,'C02528','BiGG');
INSERT INTO "substance2db" VALUES(81,'cl','BiGG+VMH');
INSERT INTO "substance2db" VALUES(82,'cholate','BiGG');
INSERT INTO "substance2db" VALUES(83,'chol','BiGG');
INSERT INTO "substance2db" VALUES(84,'chor','BiGG');
INSERT INTO "substance2db" VALUES(85,'cro4','BiGG');
INSERT INTO "substance2db" VALUES(86,'chsterol','BiGG');
INSERT INTO "substance2db" VALUES(87,'cbl1','BiGG');
INSERT INTO "substance2db" VALUES(88,'cbl2','BiGG');
INSERT INTO "substance2db" VALUES(89,'cobalt2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(90,'cu2','BiGG');
INSERT INTO "substance2db" VALUES(91,'crtstrn','BiGG');
INSERT INTO "substance2db" VALUES(91,'MNXM162953','MetaNetX');
INSERT INTO "substance2db" VALUES(92,'crtsl','BiGG');
INSERT INTO "substance2db" VALUES(92,'MNXM162531','MetaNetX');
INSERT INTO "substance2db" VALUES(93,'creat','BiGG');
INSERT INTO "substance2db" VALUES(94,'crtn','BiGG');
INSERT INTO "substance2db" VALUES(94,'MNXM163786','MetaNetX');
INSERT INTO "substance2db" VALUES(95,'cynt','BiGG');
INSERT INTO "substance2db" VALUES(96,'cgly','BiGG');
INSERT INTO "substance2db" VALUES(97,'cytd','BiGG');
INSERT INTO "substance2db" VALUES(98,'csn','BiGG');
INSERT INTO "substance2db" VALUES(99,'ala__D','BiGG');
INSERT INTO "substance2db" VALUES(100,'fru','BiGG');
INSERT INTO "substance2db" VALUES(101,'gal','BiGG');
INSERT INTO "substance2db" VALUES(102,'glc__bD','BiGG');
INSERT INTO "substance2db" VALUES(102,'glc__D','BiGG');
INSERT INTO "substance2db" VALUES(103,'lac__D','BiGG');
INSERT INTO "substance2db" VALUES(104,'man','BiGG');
INSERT INTO "substance2db" VALUES(105,'orn__D','BiGG');
INSERT INTO "substance2db" VALUES(106,'rib__D','BiGG');
INSERT INTO "substance2db" VALUES(107,'ser__D','BiGG');
INSERT INTO "substance2db" VALUES(108,'sbt__D','BiGG');
INSERT INTO "substance2db" VALUES(109,'xyl__D','BiGG');
INSERT INTO "substance2db" VALUES(110,'debrisoquine','BiGG');
INSERT INTO "substance2db" VALUES(111,'dca','BiGG');
INSERT INTO "substance2db" VALUES(111,'MNXM162295','MetaNetX');
INSERT INTO "substance2db" VALUES(112,'c10crn','BiGG');
INSERT INTO "substance2db" VALUES(113,'dhdascb','BiGG');
INSERT INTO "substance2db" VALUES(114,'dheas','BiGG');
INSERT INTO "substance2db" VALUES(115,'dad_2','BiGG');
INSERT INTO "substance2db" VALUES(116,'dchac','BiGG');
INSERT INTO "substance2db" VALUES(117,'dcyt','BiGG');
INSERT INTO "substance2db" VALUES(118,'duri','BiGG');
INSERT INTO "substance2db" VALUES(119,'dhap','BiGG');
INSERT INTO "substance2db" VALUES(120,'o2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(121,'ppi','BiGG');
INSERT INTO "substance2db" VALUES(122,'ddca','BiGG');
INSERT INTO "substance2db" VALUES(122,'MNXM162258','MetaNetX');
INSERT INTO "substance2db" VALUES(123,'dopasf','BiGG');
INSERT INTO "substance2db" VALUES(123,'MNXM163796','MetaNetX');
INSERT INTO "substance2db" VALUES(124,'vitd2','BiGG');
INSERT INTO "substance2db" VALUES(124,'MNXM163604','MetaNetX');
INSERT INTO "substance2db" VALUES(125,'estrones','BiGG');
INSERT INTO "substance2db" VALUES(125,'MNXM162533','MetaNetX');
INSERT INTO "substance2db" VALUES(126,'etoh','BiGG');
INSERT INTO "substance2db" VALUES(127,'fmn','BiGG');
INSERT INTO "substance2db" VALUES(128,'fad','BiGG');
INSERT INTO "substance2db" VALUES(129,'fald','BiGG');
INSERT INTO "substance2db" VALUES(130,'for','BiGG');
INSERT INTO "substance2db" VALUES(131,'gdp','BiGG');
INSERT INTO "substance2db" VALUES(132,'gtp','BiGG');
INSERT INTO "substance2db" VALUES(133,'gbside_hs','BiGG');
INSERT INTO "substance2db" VALUES(133,'MNXM4598','MetaNetX');
INSERT INTO "substance2db" VALUES(134,'gam','BiGG');
INSERT INTO "substance2db" VALUES(135,'glcur','BiGG');
INSERT INTO "substance2db" VALUES(136,'glyc','BiGG');
INSERT INTO "substance2db" VALUES(137,'glyc3p','BiGG');
INSERT INTO "substance2db" VALUES(138,'gly','BiGG+VMH');
INSERT INTO "substance2db" VALUES(139,'glyb','BiGG');
INSERT INTO "substance2db" VALUES(140,'dgchol','BiGG');
INSERT INTO "substance2db" VALUES(140,'MNXM8391','MetaNetX');
INSERT INTO "substance2db" VALUES(141,'gchola','BiGG');
INSERT INTO "substance2db" VALUES(141,'MNXM162346','MetaNetX');
INSERT INTO "substance2db" VALUES(142,'HC02193','BiGG');
INSERT INTO "substance2db" VALUES(143,'HC02196','BiGG');
INSERT INTO "substance2db" VALUES(144,'gsn','BiGG');
INSERT INTO "substance2db" VALUES(145,'hemeD','BiGG');
INSERT INTO "substance2db" VALUES(145,'MNXM167899','MetaNetX');
INSERT INTO "substance2db" VALUES(146,'hexc','BiGG');
INSERT INTO "substance2db" VALUES(146,'MNXM1833','MetaNetX');
INSERT INTO "substance2db" VALUES(147,'hdca','BiGG');
INSERT INTO "substance2db" VALUES(148,'hdcea','BiGG');
INSERT INTO "substance2db" VALUES(148,'MNXM950','MetaNetX');
INSERT INTO "substance2db" VALUES(149,'ha','BiGG');
INSERT INTO "substance2db" VALUES(149,'C00518','KEGG');
INSERT INTO "substance2db" VALUES(149,'MNXM18575','MetaNetX');
INSERT INTO "substance2db" VALUES(149,'cpd23482','SEED');
INSERT INTO "substance2db" VALUES(150,'h','BiGG+VMH');
INSERT INTO "substance2db" VALUES(151,'h2o2','BiGG');
INSERT INTO "substance2db" VALUES(152,'h2s','BiGG');
INSERT INTO "substance2db" VALUES(153,'hxan','BiGG');
INSERT INTO "substance2db" VALUES(154,'imp','BiGG');
INSERT INTO "substance2db" VALUES(155,'ins','BiGG');
INSERT INTO "substance2db" VALUES(156,'fe2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(157,'fe3','BiGG+VMH');
INSERT INTO "substance2db" VALUES(158,'ibt','BiGG');
INSERT INTO "substance2db" VALUES(158,'isobuta','BiGG');
INSERT INTO "substance2db" VALUES(159,'ival','BiGG');
INSERT INTO "substance2db" VALUES(160,'ivcrn','BiGG');
INSERT INTO "substance2db" VALUES(161,'abt','BiGG');
INSERT INTO "substance2db" VALUES(161,'abt__L','BiGG');
INSERT INTO "substance2db" VALUES(162,'cysi__L','BiGG');
INSERT INTO "substance2db" VALUES(163,'3aib','BiGG');
INSERT INTO "substance2db" VALUES(164,'ala__L','BiGG');
INSERT INTO "substance2db" VALUES(165,'arab__L','BiGG');
INSERT INTO "substance2db" VALUES(166,'arg__L','BiGG');
INSERT INTO "substance2db" VALUES(167,'ascb__L','BiGG');
INSERT INTO "substance2db" VALUES(168,'asn__L','BiGG');
INSERT INTO "substance2db" VALUES(169,'asp__L','BiGG');
INSERT INTO "substance2db" VALUES(170,'crn','BiGG');
INSERT INTO "substance2db" VALUES(171,'carn','BiGG');
INSERT INTO "substance2db" VALUES(171,'MNXM114412','MetaNetX');
INSERT INTO "substance2db" VALUES(171,'cpd15836','SEED');
INSERT INTO "substance2db" VALUES(172,'citr__L','BiGG');
INSERT INTO "substance2db" VALUES(173,'cys__L','BiGG');
INSERT INTO "substance2db" VALUES(174,'34dhphe','BiGG');
INSERT INTO "substance2db" VALUES(174,'MNXM162631','MetaNetX');
INSERT INTO "substance2db" VALUES(175,'glu__L','BiGG');
INSERT INTO "substance2db" VALUES(176,'gln__L','BiGG');
INSERT INTO "substance2db" VALUES(177,'glyc__S','BiGG');
INSERT INTO "substance2db" VALUES(177,'MNXM147340','MetaNetX');
INSERT INTO "substance2db" VALUES(178,'his__L','BiGG');
INSERT INTO "substance2db" VALUES(179,'hom__L','BiGG');
INSERT INTO "substance2db" VALUES(180,'ile__L','BiGG');
INSERT INTO "substance2db" VALUES(181,'lac__L','BiGG');
INSERT INTO "substance2db" VALUES(182,'leu__L','BiGG');
INSERT INTO "substance2db" VALUES(183,'lys__L','BiGG');
INSERT INTO "substance2db" VALUES(184,'mal__L','BiGG');
INSERT INTO "substance2db" VALUES(185,'mepi','BiGG');
INSERT INTO "substance2db" VALUES(185,'MNXM91238','MetaNetX');
INSERT INTO "substance2db" VALUES(186,'met__L','BiGG');
INSERT INTO "substance2db" VALUES(187,'orn__L','BiGG');
INSERT INTO "substance2db" VALUES(188,'phe__L','BiGG');
INSERT INTO "substance2db" VALUES(189,'pro__L','BiGG');
INSERT INTO "substance2db" VALUES(190,'ser__L','BiGG');
INSERT INTO "substance2db" VALUES(191,'sbt__L','BiGG');
INSERT INTO "substance2db" VALUES(192,'thr__L','BiGG');
INSERT INTO "substance2db" VALUES(193,'thyox__L','BiGG');
INSERT INTO "substance2db" VALUES(193,'MNXM162591','MetaNetX');
INSERT INTO "substance2db" VALUES(194,'trp__L','BiGG');
INSERT INTO "substance2db" VALUES(195,'tyr__L','BiGG');
INSERT INTO "substance2db" VALUES(196,'val__L','BiGG');
INSERT INTO "substance2db" VALUES(197,'gthrd','BiGG');
INSERT INTO "substance2db" VALUES(198,'pb2','BiGG');
INSERT INTO "substance2db" VALUES(198,'pb','BiGG');
INSERT INTO "substance2db" VALUES(199,'lnlc','BiGG');
INSERT INTO "substance2db" VALUES(200,'HC02191','BiGG');
INSERT INTO "substance2db" VALUES(201,'mg2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(202,'male','BiGG');
INSERT INTO "substance2db" VALUES(203,'malt','BiGG');
INSERT INTO "substance2db" VALUES(204,'mn2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(205,'hpdca','BiGG');
INSERT INTO "substance2db" VALUES(205,'MNXM11802','MetaNetX');
INSERT INTO "substance2db" VALUES(206,'mndn','BiGG');
INSERT INTO "substance2db" VALUES(207,'hg2','BiGG');
INSERT INTO "substance2db" VALUES(208,'meoh','BiGG');
INSERT INTO "substance2db" VALUES(209,'mthgxl','BiGG');
INSERT INTO "substance2db" VALUES(210,'inost','BiGG');
INSERT INTO "substance2db" VALUES(211,'fol','BiGG');
INSERT INTO "substance2db" VALUES(212,'pheacgln','BiGG');
INSERT INTO "substance2db" VALUES(212,'MNXM163884','MetaNetX');
INSERT INTO "substance2db" VALUES(213,'ncam','BiGG');
INSERT INTO "substance2db" VALUES(214,'ni2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(215,'nad','BiGG');
INSERT INTO "substance2db" VALUES(216,'nadp','BiGG');
INSERT INTO "substance2db" VALUES(217,'no3','BiGG');
INSERT INTO "substance2db" VALUES(218,'no2','BiGG');
INSERT INTO "substance2db" VALUES(219,'n2','BiGG');
INSERT INTO "substance2db" VALUES(220,'nrpphr','BiGG');
INSERT INTO "substance2db" VALUES(221,'nrpphrsf','BiGG');
INSERT INTO "substance2db" VALUES(221,'MNXM12967','MetaNetX');
INSERT INTO "substance2db" VALUES(222,'ocdca','BiGG');
INSERT INTO "substance2db" VALUES(223,'ocdcea','BiGG');
INSERT INTO "substance2db" VALUES(224,'octa','BiGG');
INSERT INTO "substance2db" VALUES(225,'c8crn','BiGG');
INSERT INTO "substance2db" VALUES(226,'c81crn','BiGG');
INSERT INTO "substance2db" VALUES(227,'elaid','BiGG');
INSERT INTO "substance2db" VALUES(227,'MNXM92305','MetaNetX');
INSERT INTO "substance2db" VALUES(228,'orot','BiGG');
INSERT INTO "substance2db" VALUES(229,'oxa','BiGG');
INSERT INTO "substance2db" VALUES(230,'gthox','BiGG');
INSERT INTO "substance2db" VALUES(231,'ptdca','BiGG');
INSERT INTO "substance2db" VALUES(231,'MNXM163568','MetaNetX');
INSERT INTO "substance2db" VALUES(232,'pi','BiGG+VMH');
INSERT INTO "substance2db" VALUES(233,'phllqne','BiGG');
INSERT INTO "substance2db" VALUES(233,'phyQ','BiGG');
INSERT INTO "substance2db" VALUES(234,'phyt','BiGG');
INSERT INTO "substance2db" VALUES(234,'MNXM91275','MetaNetX');
INSERT INTO "substance2db" VALUES(235,'k','BiGG+VMH');
INSERT INTO "substance2db" VALUES(236,'prgstrn','BiGG');
INSERT INTO "substance2db" VALUES(236,'MNXM162773','MetaNetX');
INSERT INTO "substance2db" VALUES(237,'ppa','BiGG');
INSERT INTO "substance2db" VALUES(237,'MNXM162260','MetaNetX');
INSERT INTO "substance2db" VALUES(238,'pheme','BiGG');
INSERT INTO "substance2db" VALUES(239,'ptrc','BiGG');
INSERT INTO "substance2db" VALUES(240,'nac','BiGG+VMH');
INSERT INTO "substance2db" VALUES(240,'nicnt','BiGG');
INSERT INTO "substance2db" VALUES(241,'pydx5p','BiGG');
INSERT INTO "substance2db" VALUES(242,'pyr','BiGG+VMH');
INSERT INTO "substance2db" VALUES(243,'retn','BiGG');
INSERT INTO "substance2db" VALUES(244,'retnglc','BiGG');
INSERT INTO "substance2db" VALUES(244,'MNXM91293','MetaNetX');
INSERT INTO "substance2db" VALUES(245,'rbt','BiGG');
INSERT INTO "substance2db" VALUES(246,'ribflv','BiGG+VMH');
INSERT INTO "substance2db" VALUES(247,'sarcs','BiGG');
INSERT INTO "substance2db" VALUES(248,'slnt','BiGG');
INSERT INTO "substance2db" VALUES(250,'srtn','BiGG');
INSERT INTO "substance2db" VALUES(251,'na1','BiGG+VMH');
INSERT INTO "substance2db" VALUES(252,'spmd','BiGG');
INSERT INTO "substance2db" VALUES(253,'sprm','BiGG');
INSERT INTO "substance2db" VALUES(254,'sph1p','BiGG');
INSERT INTO "substance2db" VALUES(255,'sphs1p','BiGG');
INSERT INTO "substance2db" VALUES(255,'MNXM162589','MetaNetX');
INSERT INTO "substance2db" VALUES(256,'succ','BiGG+VMH');
INSERT INTO "substance2db" VALUES(257,'sucr','BiGG');
INSERT INTO "substance2db" VALUES(258,'so4','BiGG+VMH');
INSERT INTO "substance2db" VALUES(259,'so3','BiGG');
INSERT INTO "substance2db" VALUES(260,'HC02197','BiGG');
INSERT INTO "substance2db" VALUES(261,'taur','BiGG');
INSERT INTO "substance2db" VALUES(262,'tdchola','BiGG');
INSERT INTO "substance2db" VALUES(263,'tchola','BiGG');
INSERT INTO "substance2db" VALUES(264,'tdechola','BiGG');
INSERT INTO "substance2db" VALUES(265,'HC02192','BiGG');
INSERT INTO "substance2db" VALUES(266,'tststerone','BiGG');
INSERT INTO "substance2db" VALUES(266,'MNXM162488','MetaNetX');
INSERT INTO "substance2db" VALUES(267,'lgnc','BiGG');
INSERT INTO "substance2db" VALUES(267,'MNXM8841','MetaNetX');
INSERT INTO "substance2db" VALUES(267,'lgn','BiGG');
INSERT INTO "substance2db" VALUES(268,'ttdca','BiGG');
INSERT INTO "substance2db" VALUES(268,'MNXM162239','MetaNetX');
INSERT INTO "substance2db" VALUES(269,'mobd','BiGG+VMH');
INSERT INTO "substance2db" VALUES(271,'tcynt','BiGG');
INSERT INTO "substance2db" VALUES(271,'thioc','BiGG');
INSERT INTO "substance2db" VALUES(272,'tsul','BiGG');
INSERT INTO "substance2db" VALUES(273,'HC02180','BiGG');
INSERT INTO "substance2db" VALUES(274,'thymd','BiGG');
INSERT INTO "substance2db" VALUES(275,'tungs','BiGG');
INSERT INTO "substance2db" VALUES(276,'udp','BiGG');
INSERT INTO "substance2db" VALUES(277,'udpg','BiGG');
INSERT INTO "substance2db" VALUES(278,'q10','BiGG');
INSERT INTO "substance2db" VALUES(279,'ura','BiGG');
INSERT INTO "substance2db" VALUES(280,'urate','BiGG');
INSERT INTO "substance2db" VALUES(281,'urea','BiGG+VMH');
INSERT INTO "substance2db" VALUES(282,'uri','BiGG');
INSERT INTO "substance2db" VALUES(283,'HC02194','BiGG');
INSERT INTO "substance2db" VALUES(284,'M03134','BiGG');
INSERT INTO "substance2db" VALUES(285,'b12','BiGG');
INSERT INTO "substance2db" VALUES(286,'h2o','BiGG+VMH');
INSERT INTO "substance2db" VALUES(287,'C02470','BiGG');
INSERT INTO "substance2db" VALUES(288,'xylt','BiGG');
INSERT INTO "substance2db" VALUES(289,'zn2','BiGG');
INSERT INTO "substance2db" VALUES(290,'tmndnc','BiGG');
INSERT INTO "substance2db" VALUES(290,'MNXM13045','MetaNetX');
INSERT INTO "substance2db" VALUES(291,'eicostet','BiGG');
INSERT INTO "substance2db" VALUES(291,'MNXM11474','MetaNetX');
INSERT INTO "substance2db" VALUES(292,'dlnlcg','BiGG');
INSERT INTO "substance2db" VALUES(292,'MNXM147467','MetaNetX');
INSERT INTO "substance2db" VALUES(293,'strdnc','BiGG');
INSERT INTO "substance2db" VALUES(293,'MNXM12955','MetaNetX');
INSERT INTO "substance2db" VALUES(294,'retinal','BiGG');
INSERT INTO "substance2db" VALUES(295,'retinol','BiGG');
INSERT INTO "substance2db" VALUES(296,'lnlnca','BiGG+VMH');
INSERT INTO "substance2db" VALUES(296,'alpla','BiGG');
INSERT INTO "substance2db" VALUES(297,'avite1','BiGG');
INSERT INTO "substance2db" VALUES(298,'avite2','BiGG');
INSERT INTO "substance2db" VALUES(298,'MNXM162932','MetaNetX');
INSERT INTO "substance2db" VALUES(299,'ala_B','BiGG');
INSERT INTO "substance2db" VALUES(300,'caro','BiGG');
INSERT INTO "substance2db" VALUES(301,'bvite','BiGG');
INSERT INTO "substance2db" VALUES(302,'lnlncg','BiGG');
INSERT INTO "substance2db" VALUES(302,'MNXM162504','MetaNetX');
INSERT INTO "substance2db" VALUES(303,'4hpro_LT','BiGG');
INSERT INTO "substance2db" VALUES(304,'vacc','BiGG');
INSERT INTO "substance2db" VALUES(304,'MNXM92713','MetaNetX');
INSERT INTO "substance2db" VALUES(305,'Lcyst','BiGG+VMH');
INSERT INTO "substance2db" VALUES(305,'cpd00395','SEED');
INSERT INTO "substance2db" VALUES(305,'MNXM713','MetaNetX');
INSERT INTO "substance2db" VALUES(305,'C00506','KEGG');
INSERT INTO "substance2db" VALUES(306,'oh1','BiGG+VMH');
INSERT INTO "substance2db" VALUES(306,'cpd15275','SEED');
INSERT INTO "substance2db" VALUES(306,'MNXM02','MetaNetX');
INSERT INTO "substance2db" VALUES(306,'C01328','KEGG');
INSERT INTO "substance2db" VALUES(308,'cpd24344','SEED');
INSERT INTO "substance2db" VALUES(308,'MNXM729498','MetaNetX');
INSERT INTO "substance2db" VALUES(307,'h2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(307,'cpd11640','SEED');
INSERT INTO "substance2db" VALUES(307,'MNXM1108018','MetaNetX');
INSERT INTO "substance2db" VALUES(310,'HC02023','BiGG+VMH');
INSERT INTO "substance2db" VALUES(312,'CE2510','BiGG+VMH');
INSERT INTO "substance2db" VALUES(309,'cpd00559','SEED');
INSERT INTO "substance2db" VALUES(86,'cpd00160','SEED');
INSERT INTO "substance2db" VALUES(310,'cpd10340','SEED');
INSERT INTO "substance2db" VALUES(311,'cpd09641','SEED');
INSERT INTO "substance2db" VALUES(223,'cpd00536','SEED');
INSERT INTO "substance2db" VALUES(268,'cpd03847','SEED');
INSERT INTO "substance2db" VALUES(122,'cpd01741','SEED');
INSERT INTO "substance2db" VALUES(147,'cpd00214','SEED');
INSERT INTO "substance2db" VALUES(111,'cpd01107','SEED');
INSERT INTO "substance2db" VALUES(205,'cpd24916','SEED');
INSERT INTO "substance2db" VALUES(222,'cpd01080','SEED');
INSERT INTO "substance2db" VALUES(60,'cpd03848','SEED');
INSERT INTO "substance2db" VALUES(63,'cpd05196','SEED');
INSERT INTO "substance2db" VALUES(267,'cpd05235','SEED');
INSERT INTO "substance2db" VALUES(148,'cpd05274','SEED');
INSERT INTO "substance2db" VALUES(312,'cpd16341','SEED');
INSERT INTO "substance2db" VALUES(199,'cpd01122','SEED');
INSERT INTO "substance2db" VALUES(75,'cpd00063','SEED');
INSERT INTO "substance2db" VALUES(156,'cpd10515','SEED');
INSERT INTO "substance2db" VALUES(157,'cpd10516','SEED');
INSERT INTO "substance2db" VALUES(286,'cpd00001','SEED');
INSERT INTO "substance2db" VALUES(83,'cpd00098','SEED');
INSERT INTO "substance2db" VALUES(297,'cpd01628','SEED');
INSERT INTO "substance2db" VALUES(233,'cpd01401','SEED');
INSERT INTO "substance2db" VALUES(235,'cpd00205','SEED');
INSERT INTO "substance2db" VALUES(251,'cpd00971','SEED');
INSERT INTO "substance2db" VALUES(67,'cpd00211','SEED');
INSERT INTO "substance2db" VALUES(224,'cpd03846','SEED');
INSERT INTO "substance2db" VALUES(231,'cpd16351','SEED');
INSERT INTO "substance2db" VALUES(289,'cpd00034','SEED');
INSERT INTO "substance2db" VALUES(296,'cpd03850','SEED');
INSERT INTO "substance2db" VALUES(61,'cpd00188','SEED');
INSERT INTO "substance2db" VALUES(309,'MNXM1104376','MetaNetX');
INSERT INTO "substance2db" VALUES(86,'MNXM726122','MetaNetX');
INSERT INTO "substance2db" VALUES(310,'MNXM730830','MetaNetX');
INSERT INTO "substance2db" VALUES(311,'MNXM9612','MetaNetX');
INSERT INTO "substance2db" VALUES(223,'MNXM1107708','MetaNetX');
INSERT INTO "substance2db" VALUES(268,'MNXM314','MetaNetX');
INSERT INTO "substance2db" VALUES(122,'MNXM402','MetaNetX');
INSERT INTO "substance2db" VALUES(147,'MNXM108','MetaNetX');
INSERT INTO "substance2db" VALUES(111,'MNXM1043','MetaNetX');
INSERT INTO "substance2db" VALUES(222,'MNXM236','MetaNetX');
INSERT INTO "substance2db" VALUES(60,'MNXM2976','MetaNetX');
INSERT INTO "substance2db" VALUES(63,'MNXM7102','MetaNetX');
INSERT INTO "substance2db" VALUES(267,'MNXM3297','MetaNetX');
INSERT INTO "substance2db" VALUES(148,'MNXM1107900','MetaNetX');
INSERT INTO "substance2db" VALUES(312,'MNXM1107952','MetaNetX');
INSERT INTO "substance2db" VALUES(199,'MNXM1108069','MetaNetX');
INSERT INTO "substance2db" VALUES(75,'MNXM128','MetaNetX');
INSERT INTO "substance2db" VALUES(156,'MNXM726711','MetaNetX');
INSERT INTO "substance2db" VALUES(157,'MNXM726712','MetaNetX');
INSERT INTO "substance2db" VALUES(286,'WATER','MetaNetX');
INSERT INTO "substance2db" VALUES(83,'MNXM90','MetaNetX');
INSERT INTO "substance2db" VALUES(297,'MNXM2741','MetaNetX');
INSERT INTO "substance2db" VALUES(233,'MNXM1106873','MetaNetX');
INSERT INTO "substance2db" VALUES(235,'MNXM95','MetaNetX');
INSERT INTO "substance2db" VALUES(251,'MNXM27','MetaNetX');
INSERT INTO "substance2db" VALUES(67,'MNXM458','MetaNetX');
INSERT INTO "substance2db" VALUES(224,'MNXM750','MetaNetX');
INSERT INTO "substance2db" VALUES(231,'MNXM12597','MetaNetX');
INSERT INTO "substance2db" VALUES(289,'MNXM729215','MetaNetX');
INSERT INTO "substance2db" VALUES(296,'MNXM1108303','MetaNetX');
INSERT INTO "substance2db" VALUES(61,'MNXM1107770','MetaNetX');
INSERT INTO "substance2db" VALUES(309,'C00751','KEGG');
INSERT INTO "substance2db" VALUES(86,'C00187','KEGG');
INSERT INTO "substance2db" VALUES(310,'C14641','KEGG');
INSERT INTO "substance2db" VALUES(311,'C13821','KEGG');
INSERT INTO "substance2db" VALUES(223,'C00712','KEGG');
INSERT INTO "substance2db" VALUES(268,'C06424','KEGG');
INSERT INTO "substance2db" VALUES(122,'C02679','KEGG');
INSERT INTO "substance2db" VALUES(147,'C00249','KEGG');
INSERT INTO "substance2db" VALUES(111,'C01571','KEGG');
INSERT INTO "substance2db" VALUES(222,'C01530','KEGG');
INSERT INTO "substance2db" VALUES(60,'C06425','KEGG');
INSERT INTO "substance2db" VALUES(63,'C08281','KEGG');
INSERT INTO "substance2db" VALUES(199,'C01595','KEGG');
INSERT INTO "substance2db" VALUES(75,'C00076','KEGG');
INSERT INTO "substance2db" VALUES(156,'C14818','KEGG');
INSERT INTO "substance2db" VALUES(157,'C14819','KEGG');
INSERT INTO "substance2db" VALUES(286,'C00001','KEGG');
INSERT INTO "substance2db" VALUES(83,'C00114','KEGG');
INSERT INTO "substance2db" VALUES(297,'C02477','KEGG');
INSERT INTO "substance2db" VALUES(233,'C02059','KEGG');
INSERT INTO "substance2db" VALUES(235,'C00238','KEGG');
INSERT INTO "substance2db" VALUES(251,'C01330','KEGG');
INSERT INTO "substance2db" VALUES(67,'C00246','KEGG');
INSERT INTO "substance2db" VALUES(224,'C06423','KEGG');
INSERT INTO "substance2db" VALUES(289,'C00038','KEGG');
INSERT INTO "substance2db" VALUES(61,'C00219','KEGG');
INSERT INTO "substance2db" VALUES(309,'sql','BiGG+VMH');
INSERT INTO "substance2db" VALUES(81,'cpd00099','SEED');
INSERT INTO "substance2db" VALUES(242,'cpd00020','SEED');
INSERT INTO "substance2db" VALUES(232,'cpd00009','SEED');
INSERT INTO "substance2db" VALUES(150,'cpd00067','SEED');
INSERT INTO "substance2db" VALUES(258,'cpd00048','SEED');
INSERT INTO "substance2db" VALUES(78,'cpd00242','SEED');
INSERT INTO "substance2db" VALUES(102,'cpd00027','SEED');
INSERT INTO "substance2db" VALUES(138,'cpd00033','SEED');
INSERT INTO "substance2db" VALUES(182,'cpd00107','SEED');
INSERT INTO "substance2db" VALUES(190,'cpd00054','SEED');
INSERT INTO "substance2db" VALUES(164,'cpd00035','SEED');
INSERT INTO "substance2db" VALUES(166,'cpd00051','SEED');
INSERT INTO "substance2db" VALUES(178,'cpd00119','SEED');
INSERT INTO "substance2db" VALUES(196,'cpd00156','SEED');
INSERT INTO "substance2db" VALUES(180,'cpd00322','SEED');
INSERT INTO "substance2db" VALUES(183,'cpd00039','SEED');
INSERT INTO "substance2db" VALUES(188,'cpd00066','SEED');
INSERT INTO "substance2db" VALUES(195,'cpd00069','SEED');
INSERT INTO "substance2db" VALUES(176,'cpd00053','SEED');
INSERT INTO "substance2db" VALUES(169,'cpd00041','SEED');
INSERT INTO "substance2db" VALUES(175,'cpd00023','SEED');
INSERT INTO "substance2db" VALUES(189,'cpd00129','SEED');
INSERT INTO "substance2db" VALUES(187,'cpd00064','SEED');
INSERT INTO "substance2db" VALUES(172,'cpd00274','SEED');
INSERT INTO "substance2db" VALUES(194,'cpd00065','SEED');
INSERT INTO "substance2db" VALUES(168,'cpd00132','SEED');
INSERT INTO "substance2db" VALUES(192,'cpd00161','SEED');
INSERT INTO "substance2db" VALUES(81,'MNXM735978','MetaNetX');
INSERT INTO "substance2db" VALUES(242,'MNXM23','MetaNetX');
INSERT INTO "substance2db" VALUES(232,'MNXM9','MetaNetX');
INSERT INTO "substance2db" VALUES(150,'MNXM1','MetaNetX');
INSERT INTO "substance2db" VALUES(258,'MNXM58','MetaNetX');
INSERT INTO "substance2db" VALUES(78,'MNXM60','MetaNetX');
INSERT INTO "substance2db" VALUES(102,'MNXM1137670','MetaNetX');
INSERT INTO "substance2db" VALUES(138,'MNXM29','MetaNetX');
INSERT INTO "substance2db" VALUES(182,'MNXM1106761','MetaNetX');
INSERT INTO "substance2db" VALUES(190,'MNXM737787','MetaNetX');
INSERT INTO "substance2db" VALUES(164,'MNXM1105732','MetaNetX');
INSERT INTO "substance2db" VALUES(166,'MNXM739527','MetaNetX');
INSERT INTO "substance2db" VALUES(178,'MNXM1107769','MetaNetX');
INSERT INTO "substance2db" VALUES(196,'MNXM199','MetaNetX');
INSERT INTO "substance2db" VALUES(180,'MNXM728337','MetaNetX');
INSERT INTO "substance2db" VALUES(183,'MNXM1106164','MetaNetX');
INSERT INTO "substance2db" VALUES(188,'MNXM741664','MetaNetX');
INSERT INTO "substance2db" VALUES(195,'MNXM76','MetaNetX');
INSERT INTO "substance2db" VALUES(176,'MNXM37','MetaNetX');
INSERT INTO "substance2db" VALUES(169,'MNXM1108206','MetaNetX');
INSERT INTO "substance2db" VALUES(175,'MNXM741173','MetaNetX');
INSERT INTO "substance2db" VALUES(189,'MNXM114','MetaNetX');
INSERT INTO "substance2db" VALUES(187,'MNXM741175','MetaNetX');
INSERT INTO "substance2db" VALUES(172,'MNXM732471','MetaNetX');
INSERT INTO "substance2db" VALUES(194,'MNXM741553','MetaNetX');
INSERT INTO "substance2db" VALUES(168,'MNXM1107821','MetaNetX');
INSERT INTO "substance2db" VALUES(192,'MNXM142','MetaNetX');
INSERT INTO "substance2db" VALUES(102,'glc_D','VMH');
INSERT INTO "substance2db" VALUES(182,'leu_L','VMH');
INSERT INTO "substance2db" VALUES(190,'ser_L','VMH');
INSERT INTO "substance2db" VALUES(164,'ala_L','VMH');
INSERT INTO "substance2db" VALUES(166,'arg_L','VMH');
INSERT INTO "substance2db" VALUES(178,'his_L','VMH');
INSERT INTO "substance2db" VALUES(196,'val_L','VMH');
INSERT INTO "substance2db" VALUES(180,'ile_L','VMH');
INSERT INTO "substance2db" VALUES(183,'lys_L','VMH');
INSERT INTO "substance2db" VALUES(188,'phe_L','VMH');
INSERT INTO "substance2db" VALUES(195,'tyr_L','VMH');
INSERT INTO "substance2db" VALUES(176,'gln_L','VMH');
INSERT INTO "substance2db" VALUES(169,'asp_L','VMH');
INSERT INTO "substance2db" VALUES(175,'glu_L','VMH');
INSERT INTO "substance2db" VALUES(189,'pro_L','VMH');
INSERT INTO "substance2db" VALUES(187,'orn','VMH');
INSERT INTO "substance2db" VALUES(172,'citr_L','VMH');
INSERT INTO "substance2db" VALUES(194,'trp_L','VMH');
INSERT INTO "substance2db" VALUES(168,'asn_L','VMH');
INSERT INTO "substance2db" VALUES(192,'thr_L','VMH');
INSERT INTO "substance2db" VALUES(81,'C00698','KEGG');
INSERT INTO "substance2db" VALUES(242,'C00022','KEGG');
INSERT INTO "substance2db" VALUES(232,'C00009','KEGG');
INSERT INTO "substance2db" VALUES(150,'C00080','KEGG');
INSERT INTO "substance2db" VALUES(258,'C00059','KEGG');
INSERT INTO "substance2db" VALUES(78,'C00288','KEGG');
INSERT INTO "substance2db" VALUES(102,'C00031','KEGG');
INSERT INTO "substance2db" VALUES(138,'C00037','KEGG');
INSERT INTO "substance2db" VALUES(182,'C00123','KEGG');
INSERT INTO "substance2db" VALUES(190,'C00065','KEGG');
INSERT INTO "substance2db" VALUES(164,'C00041','KEGG');
INSERT INTO "substance2db" VALUES(166,'C00062','KEGG');
INSERT INTO "substance2db" VALUES(178,'C00135','KEGG');
INSERT INTO "substance2db" VALUES(196,'C00183','KEGG');
INSERT INTO "substance2db" VALUES(180,'C00407','KEGG');
INSERT INTO "substance2db" VALUES(183,'C00047','KEGG');
INSERT INTO "substance2db" VALUES(188,'C00079','KEGG');
INSERT INTO "substance2db" VALUES(195,'C00082','KEGG');
INSERT INTO "substance2db" VALUES(176,'C00064','KEGG');
INSERT INTO "substance2db" VALUES(169,'C00049','KEGG');
INSERT INTO "substance2db" VALUES(175,'C00025','KEGG');
INSERT INTO "substance2db" VALUES(189,'C00148','KEGG');
INSERT INTO "substance2db" VALUES(187,'C00077','KEGG');
INSERT INTO "substance2db" VALUES(172,'C00327','KEGG');
INSERT INTO "substance2db" VALUES(194,'C00078','KEGG');
INSERT INTO "substance2db" VALUES(168,'C00152','KEGG');
INSERT INTO "substance2db" VALUES(192,'C00188','KEGG');
INSERT INTO "substance2db" VALUES(89,'cpd00149','SEED');
INSERT INTO "substance2db" VALUES(201,'cpd00254','SEED');
INSERT INTO "substance2db" VALUES(120,'cpd00007','SEED');
INSERT INTO "substance2db" VALUES(270,'cpd00305','SEED');
INSERT INTO "substance2db" VALUES(66,'cpd00104','SEED');
INSERT INTO "substance2db" VALUES(240,'cpd00218','SEED');
INSERT INTO "substance2db" VALUES(25,'cpd00644','SEED');
INSERT INTO "substance2db" VALUES(56,'MNXM729302','MetaNetX');
INSERT INTO "substance2db" VALUES(89,'MNXM90960','MetaNetX');
INSERT INTO "substance2db" VALUES(201,'MNXM653','MetaNetX');
INSERT INTO "substance2db" VALUES(120,'MNXM735438','MetaNetX');
INSERT INTO "substance2db" VALUES(270,'MNXM730135','MetaNetX');
INSERT INTO "substance2db" VALUES(66,'MNXM304','MetaNetX');
INSERT INTO "substance2db" VALUES(240,'MNXM274','MetaNetX');
INSERT INTO "substance2db" VALUES(25,'MNXM734864','MetaNetX');
INSERT INTO "substance2db" VALUES(25,'pnto_R','VMH');
INSERT INTO "substance2db" VALUES(56,'C00014','KEGG');
INSERT INTO "substance2db" VALUES(56,'C01342','KEGG');
INSERT INTO "substance2db" VALUES(89,'C00175','KEGG');
INSERT INTO "substance2db" VALUES(201,'C00305','KEGG');
INSERT INTO "substance2db" VALUES(120,'C00007','KEGG');
INSERT INTO "substance2db" VALUES(270,'C00378','KEGG');
INSERT INTO "substance2db" VALUES(66,'C00120','KEGG');
INSERT INTO "substance2db" VALUES(240,'C00253','KEGG');
INSERT INTO "substance2db" VALUES(25,'C00864','KEGG');
INSERT INTO "substance2db" VALUES(314,'selmeth','BiGG');
INSERT INTO "substance2db" VALUES(315,'gglusem','BiGG');
INSERT INTO "substance2db" VALUES(316,'seahcys','BiGG');
INSERT INTO "substance2db" VALUES(317,'o2s','BiGG+VMH');
INSERT INTO "substance2db" VALUES(317,'C00704','KEGG');
INSERT INTO "substance2db" VALUES(317,'sox','BiGG');
INSERT INTO "substance2db" VALUES(317,'MNXM1094127','MetaNetX');
INSERT INTO "substance2db" VALUES(317,'MNXM1107906','MetaNetX');
INSERT INTO "substance2db" VALUES(317,'MNXM1107908','MetaNetX');
INSERT INTO "substance2db" VALUES(317,'cpd00532','SEED');
INSERT INTO "substance2db" VALUES(318,'cpd00052','SEED');
INSERT INTO "substance2db" VALUES(319,'cpd00062','SEED');
INSERT INTO "substance2db" VALUES(320,'cpd00068','SEED');
INSERT INTO "substance2db" VALUES(321,'cpd00090','SEED');
INSERT INTO "substance2db" VALUES(322,'cpd00004','SEED');
INSERT INTO "substance2db" VALUES(323,'cpd00005','SEED');
INSERT INTO "substance2db" VALUES(324,'cpd00982','SEED');
INSERT INTO "substance2db" VALUES(325,'cpd01270','SEED');
INSERT INTO "substance2db" VALUES(326,'cpd15561','SEED');
INSERT INTO "substance2db" VALUES(327,'cpd15560','SEED');
INSERT INTO "substance2db" VALUES(328,'cpd15499','SEED');
INSERT INTO "substance2db" VALUES(329,'cpd15500','SEED');
INSERT INTO "substance2db" VALUES(330,'cpd15353','SEED');
INSERT INTO "substance2db" VALUES(331,'cpd15352','SEED');
INSERT INTO "substance2db" VALUES(332,'cpd00022','SEED');
INSERT INTO "substance2db" VALUES(51,'cpd00029','SEED');
INSERT INTO "substance2db" VALUES(334,'cpd00010','SEED');
INSERT INTO "substance2db" VALUES(318,'MNXM1103718','MetaNetX');
INSERT INTO "substance2db" VALUES(319,'MNXM1101474','MetaNetX');
INSERT INTO "substance2db" VALUES(320,'MNXM1103428','MetaNetX');
INSERT INTO "substance2db" VALUES(321,'MNXM1104559','MetaNetX');
INSERT INTO "substance2db" VALUES(322,'MNXM10','MetaNetX');
INSERT INTO "substance2db" VALUES(323,'MNXM738702','MetaNetX');
INSERT INTO "substance2db" VALUES(324,'MNXM1105762','MetaNetX');
INSERT INTO "substance2db" VALUES(325,'MNXM1107623','MetaNetX');
INSERT INTO "substance2db" VALUES(326,'MNXM191','MetaNetX');
INSERT INTO "substance2db" VALUES(327,'MNXM232','MetaNetX');
INSERT INTO "substance2db" VALUES(328,'MNXM223','MetaNetX');
INSERT INTO "substance2db" VALUES(329,'MNXM509','MetaNetX');
INSERT INTO "substance2db" VALUES(330,'MNXM558','MetaNetX');
INSERT INTO "substance2db" VALUES(331,'MNXM2178','MetaNetX');
INSERT INTO "substance2db" VALUES(332,'MNXM1104266','MetaNetX');
INSERT INTO "substance2db" VALUES(51,'MNXM26','MetaNetX');
INSERT INTO "substance2db" VALUES(334,'MNXM727276','MetaNetX');
INSERT INTO "substance2db" VALUES(318,'C00063','KEGG');
INSERT INTO "substance2db" VALUES(319,'C00075','KEGG');
INSERT INTO "substance2db" VALUES(320,'C00081','KEGG');
INSERT INTO "substance2db" VALUES(321,'C00104','KEGG');
INSERT INTO "substance2db" VALUES(322,'C00004','KEGG');
INSERT INTO "substance2db" VALUES(323,'C00005','KEGG');
INSERT INTO "substance2db" VALUES(324,'C01352','KEGG');
INSERT INTO "substance2db" VALUES(325,'C01847','KEGG');
INSERT INTO "substance2db" VALUES(326,'C00390','KEGG');
INSERT INTO "substance2db" VALUES(327,'C17569','KEGG');
INSERT INTO "substance2db" VALUES(328,'C05819','KEGG');
INSERT INTO "substance2db" VALUES(329,'C00828','KEGG');
INSERT INTO "substance2db" VALUES(330,'C19847','KEGG');
INSERT INTO "substance2db" VALUES(331,'C05818','KEGG');
INSERT INTO "substance2db" VALUES(332,'C00024','KEGG');
INSERT INTO "substance2db" VALUES(51,'C00033','KEGG');
INSERT INTO "substance2db" VALUES(334,'C00010','KEGG');
INSERT INTO "substance2db" VALUES(318,'ctp','BiGG+VMH');
INSERT INTO "substance2db" VALUES(319,'utp','BiGG+VMH');
INSERT INTO "substance2db" VALUES(320,'itp','BiGG+VMH');
INSERT INTO "substance2db" VALUES(321,'idp','BiGG+VMH');
INSERT INTO "substance2db" VALUES(322,'nadh','BiGG+VMH');
INSERT INTO "substance2db" VALUES(323,'nadph','BiGG+VMH');
INSERT INTO "substance2db" VALUES(324,'fadh2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(325,'fmnh2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(326,'q8h2','BiGG+VMH');
INSERT INTO "substance2db" VALUES(327,'q8','BiGG+VMH');
INSERT INTO "substance2db" VALUES(328,'mql8','BiGG+VMH');
INSERT INTO "substance2db" VALUES(329,'mqn8','BiGG+VMH');
INSERT INTO "substance2db" VALUES(330,'2dmmql8','BiGG+VMH');
INSERT INTO "substance2db" VALUES(331,'2dmmq8','BiGG+VMH');
INSERT INTO "substance2db" VALUES(332,'accoa','BiGG+VMH');
INSERT INTO "substance2db" VALUES(334,'coa','BiGG+VMH');
INSERT INTO "substance2db" VALUES(4,'C00122','KEGG');
INSERT INTO "substance2db" VALUES(16,'C00158','KEGG');
INSERT INTO "substance2db" VALUES(27,'C00534','KEGG');
INSERT INTO "substance2db" VALUES(28,'C00568','KEGG');
INSERT INTO "substance2db" VALUES(76,'C00011','KEGG');
INSERT INTO "substance2db" VALUES(87,'C00853','KEGG');
INSERT INTO "substance2db" VALUES(88,'C00541','KEGG');
INSERT INTO "substance2db" VALUES(90,'C22424','KEGG');
INSERT INTO "substance2db" VALUES(105,'C00515','KEGG');
INSERT INTO "substance2db" VALUES(173,'C00097','KEGG');
INSERT INTO "substance2db" VALUES(202,'C01384','KEGG');
INSERT INTO "substance2db" VALUES(204,'C19610','KEGG');
INSERT INTO "substance2db" VALUES(214,'C18912','KEGG');
INSERT INTO "substance2db" VALUES(246,'C00255','KEGG');
INSERT INTO "substance2db" VALUES(256,'C00042','KEGG');
INSERT INTO "substance2db" VALUES(269,'C06232','KEGG');
INSERT INTO "substance2db" VALUES(281,'C00086','KEGG');
INSERT INTO "substance2db" VALUES(285,'C05776','KEGG');
INSERT INTO "substance2db" VALUES(4,'MNXM737340','MetaNetX');
INSERT INTO "substance2db" VALUES(16,'MNXM1107753','MetaNetX');
INSERT INTO "substance2db" VALUES(27,'MNXM548','MetaNetX');
INSERT INTO "substance2db" VALUES(28,'MNXM421','MetaNetX');
INSERT INTO "substance2db" VALUES(76,'MNXM13','MetaNetX');
INSERT INTO "substance2db" VALUES(87,'MNXM1104756','MetaNetX');
INSERT INTO "substance2db" VALUES(88,'MNXM1104738','MetaNetX');
INSERT INTO "substance2db" VALUES(90,'MNXM731166','MetaNetX');
INSERT INTO "substance2db" VALUES(105,'MNXM1148','MetaNetX');
INSERT INTO "substance2db" VALUES(173,'MNXM738068','MetaNetX');
INSERT INTO "substance2db" VALUES(202,'MNXM1239','MetaNetX');
INSERT INTO "substance2db" VALUES(204,'MNXM2255','MetaNetX');
INSERT INTO "substance2db" VALUES(214,'MNXM731950','MetaNetX');
INSERT INTO "substance2db" VALUES(246,'MNXM270','MetaNetX');
INSERT INTO "substance2db" VALUES(256,'MNXM25','MetaNetX');
INSERT INTO "substance2db" VALUES(269,'MNXM726092','MetaNetX');
INSERT INTO "substance2db" VALUES(281,'MNXM117','MetaNetX');
INSERT INTO "substance2db" VALUES(285,'MNXM736799','MetaNetX');
INSERT INTO "substance2db" VALUES(4,'cpd00106','SEED');
INSERT INTO "substance2db" VALUES(16,'cpd00137','SEED');
INSERT INTO "substance2db" VALUES(27,'cpd00419','SEED');
INSERT INTO "substance2db" VALUES(28,'cpd00443','SEED');
INSERT INTO "substance2db" VALUES(76,'cpd00011','SEED');
INSERT INTO "substance2db" VALUES(87,'cpd00635','SEED');
INSERT INTO "substance2db" VALUES(88,'cpd00423','SEED');
INSERT INTO "substance2db" VALUES(90,'cpd00058','SEED');
INSERT INTO "substance2db" VALUES(105,'cpd00404','SEED');
INSERT INTO "substance2db" VALUES(173,'cpd00084','SEED');
INSERT INTO "substance2db" VALUES(202,'cpd00996','SEED');
INSERT INTO "substance2db" VALUES(204,'cpd00030','SEED');
INSERT INTO "substance2db" VALUES(214,'cpd00244','SEED');
INSERT INTO "substance2db" VALUES(246,'cpd00220','SEED');
INSERT INTO "substance2db" VALUES(256,'cpd00036','SEED');
INSERT INTO "substance2db" VALUES(269,'cpd11574','SEED');
INSERT INTO "substance2db" VALUES(281,'cpd00073','SEED');
INSERT INTO "substance2db" VALUES(285,'cpd03424','SEED');
INSERT INTO "substance2db" VALUES(105,'orn_D','VMH');
INSERT INTO "substance2db" VALUES(173,'cys_L','VMH');
